package
{
	import UI.Atlas;
    import cocos2d.Cocos2D;
	import cocos2d.Cocos2DGame;
	import cocos2d.CCScaledLayer;
	import cocos2d.ScaleMode;
	
	import constants.Resources;
	import constants.States;
	import logic.MainPlayer;
	import logic.PlayerManager;
	import state.GameStateManager;
	import state.StateDS;
	import state.StateMainMenu;
	import state.StatePlay;

	/**
	 * Our main HeadUp game class
	 */
	public class HeadsUp extends Cocos2DGame
	{
		
		/**********************************************************************/
		
		/**
		 * The PlayerManager that stores our player info
		 */
		public var playerManager:PlayerManager = null;
		
		/**
		 * The GameStateManager that will drive the game
		 */
		public var stateManager:GameStateManager = null;
		
		/**
		 * The layer to add all our gui stuff to
		 */
		public var guiCanvas:CCScaledLayer = null;
		
		/**
		 * The main player object, holding our money, stats etc
		 */
		public var mainPlayer:MainPlayer = null;
		
		/**********************************************************************/
		
		override public function run():void
		{
			// comment out this line to turn off automatic scaling
			this.layer.scaleMode 	= ScaleMode.LETTERBOX;
			this.layer.designWidth	= 640.0;
			this.layer.designHeight	= 480.0;
			
			super.run();
			
			// register our sprites
			Atlas.register( Resources.ATLAS_SPRITES, Resources.ASSETS_FOLDER );
			Atlas.register( Resources.ATLAS_BACKGROUNDS, Resources.ASSETS_FOLDER );
			Atlas.register( Resources.ATLAS_BUTTONS, Resources.ASSETS_FOLDER );
			
			// create our gui canvas
			this.guiCanvas 				= new CCScaledLayer();
			this.guiCanvas.scaleMode	= this.layer.scaleMode;
			this.guiCanvas.designWidth	= this.layer.designWidth;
			this.guiCanvas.designHeight	= this.layer.designHeight;
			this.group.registerManager( this.guiCanvas, null, "guiCanvas" );
			Cocos2D.addLayer( this.guiCanvas );
			
			// create our player manager
			this.playerManager = new PlayerManager();
			this.playerManager.createFromXML( Resources.XML_PLAYERS );
			this.group.registerManager( this.playerManager );
			
			// create our main player
			this.mainPlayer = new MainPlayer();
			this.group.registerManager( this.mainPlayer );
			
			// create our game state manager
			this.stateManager = new GameStateManager( this.group.getInjector() );
			this.group.registerManager( this.stateManager );
			
			// add our states
			this.stateManager.addState( new StateDS );	
			this.stateManager.addState( new StateMainMenu );
			this.stateManager.addState( new StatePlay );
			
			// change to our starting state (comment in/out the other lines to start directly at that state)
			this.stateManager.changeState( States.DS );
			// this.stateManager.changeState( States.MENU );
			// this.stateManager.changeState( States.PLAY, this.playerManager.getPlayerByIndex( 0 ) );
		}
	}
}