package constants
{
	import enums.BetRound;

	/**
	 * The PokerStates class holds the constants for names used in our poker game states
	 */
	public class PokerStates
	{
		
		/**********************************************************************/
		
		/**
		 * The dealer state where we set/change the dealer
		 */
		public static const DEALER:String = "Dealer";
		
		/**
		 * The pre-flop, where we deal the hole cards
		 */
		public static const PRE_FLOP:String = "PreFlop";
		
		/**
		 * The flop, where we deal the first 3 table cards
		 */
		public static const FLOP:String = "Flop";
		
		/**
		 * The turn, where we deal the fourth table card
		 */
		public static const TURN:String = "Turn";
		
		/**
		 * The river, where we deal the fifth table card
		 */
		public static const RIVER:String = "River";
		
		/**
		 * The state where we figure out who's won (this does not count when one of the players has folded)
		 */
		public static const WINNER:String = "Winner";
		
		/**
		 * The state where the player can bet on hands etc
		 */
		public static const BET:String = "Bet";
		
		/**
		 * The state where we show the player their end match stats
		 */
		public static const END_MATCH:String = "EndMatch";
		
		/**
		 * The state where we go to wait
		 */
		public static const WAIT:String = "Wait";
		
		/**********************************************************************/
		
		/**
		 * Checks if a state is valid
		 * @param state The state that we're checking
		 * @return True if it's a valid PokerState, false otherwise
		 */
		public static function isValid( state:String ):Boolean
		{
			if( state == PokerStates.DEALER ||
				state == PokerStates.PRE_FLOP ||
				state == PokerStates.FLOP ||
				state == PokerStates.TURN ||
				state == PokerStates.RIVER ||
				state == PokerStates.WINNER ||
				state == PokerStates.BET ||
				state == PokerStates.END_MATCH ||
				state == PokerStates.WAIT )
				return true;
			
			Console.print( "[PokerStates] ERROR: Invalid state: " + state );
			return false;
		}
		
		/**
		 * Gets the next state to go to
		 * @param state The state that we're looking for the next one of
		 * @return The name of the next state, or null if we don't have it
		 */
		public static function getNextState( state:String ):String
		{
			// NOTE: this is only really meant to be used by the bet state, so some
			// valid PokerStates don't have a next one
			if( state == PokerStates.PRE_FLOP )
				return PokerStates.FLOP;
			else if( state == PokerStates.FLOP )
				return PokerStates.TURN;
			else if( state == PokerStates.TURN )
				return PokerStates.RIVER;
			else if( state == PokerStates.RIVER )
				return PokerStates.WINNER;
			else if( state == PokerStates.WINNER )
				return PokerStates.PRE_FLOP;
			
			Console.print( "[PokerStates] ERROR: Can't find the next state for state: " + state );
			return null;
		}
		
		/**
		 * Gets the BetRound for a specific state
		 * @params state The state that we're looking for the BetRound for
		 * @return The BetRound for this state
		 */
		public static function getBetRound( state:String ):BetRound
		{
			// we're only interested in the betting states
			if( state == PokerStates.PRE_FLOP )
				return BetRound.PRE_FLOP;
			else if( state == PokerStates.FLOP )
				return BetRound.FLOP;
			else if( state == PokerStates.TURN )
				return BetRound.TURN;
			else if( state == PokerStates.RIVER )
				return BetRound.RIVER;
			
			// this isn't a betting round
			return BetRound.NONE;
		}
	}
	
}