package gui
{
	import cocos2d.CCRect;
	import cocos2d.CCPoint;
	import UI.Button;
	
	/**
	 * Define a delegate for a button callback, passing this as a parameter
	 */
	public delegate BtnCallback( btn:Btn ):void;
	
	/**
	 * An Btn class, which wraps Button and provides some convenience methods
	 */
	public class Btn extends Button
	{
		
		/**********************************************************************/
		
		/**
		 * The delegate for when we click the button (onClick exists, but it doesn't return
		 * the button or anything)
		 */
		public var onBtnClick:BtnCallback = null;
		
		/**********************************************************************/
		
		private var m_width:int 	= 0.0; // the width of the Btn
		private var m_height:int 	= 0.0; // the height of the Btn
		
		/**********************************************************************/
		
		/**
		 * The width of the Btn
		 */
		public function get width():int { return this.m_width; }
		
		/**
		 * The height of the Btn
		 */
		public function get height():int { return this.m_height; }
		
		/**
		 * Sets the rotation for the Btn
		 */
		public function get rotation():Number { return this.getRotation(); }
		
		/**
		 * Sets the x scale for the Btn
		 */
		override public function get scaleX():Number { return super.getScaleX(); }
		override public function set scaleX( n:Number ):void
		{
			super.setScaleX( n );
			this._calcWidthAndHeight();
		}
		
		/**
		 * Sets the y scale for the Btn
		 */
		override public function get scaleY():Number { return super.getScaleY(); }
		override public function set scaleY( n:Number ):void
		{
			super.setScaleY( n );
			this._calcWidthAndHeight();
		}
		
		/**
		 * Sets the scale for the Btn
		 */
		override public function get scale():Number { return super.getScale(); }
		override public function set scale( n:Number ):void
		{
			super.setScale( n );
			this._calcWidthAndHeight();
		}
		
		/**
		 * The alpha for the Btn
		 */
		public function get alpha():Number
		{
			var o:int = this.getOpacity();
			return ( o < 0 ) ? 0.0 : ( o > 255 ) ? 1.0 : o / 255.0;
		}
		public function set alpha( n:Number ):void
		{
			n = ( n < 0.0 ) ? 0.0 : ( n > 1.0 ) ? 1.0 : n;
			this.setOpacity( n * 255 );
		}
		
		/**********************************************************************/
		
		/**
		 * Creates a new Btn
		 * @param upImage The image to use for the up state of the button
		 * @param downImage The image to use for the down state of the button
		 * @param atlasID The ID of the atlas texture
		 */
		public function Btn( upImage:String = null, downImage:String = null, atlasID:String = null )
		{
			super( upImage, downImage, atlasID );
			
			// set our anchor point to the top left corner
			this.setAnchorPoint( new CCPoint( 0.0, 1.0 ) );
			
			// calculate our width and height
			this._calcWidthAndHeight();
			
			// set our onclick
			this.onClick += this._onClick;
		}
		
		/**
		 * Destroys the Btn and clears it for garbage collection
		 */
		public function destroy():void
		{
			// remove us
			if( this.getParent() != null )
				this.getParent().removeChild( this, true );
				
			// remove all our children
			this.removeAllChildrenWithCleanup( true );
			
			// clear our delegates
			this.onBtnClick			= null;
			this.onClick			= null;
			this.onTouchBegan		= null;
			this.onTouchMoved		= null;
			this.onTouchEnded		= null;
			this.onTouchCancelled	= null;
		}
		
		/**
		 * Sets the rotation for the Btn
		 */
		override public function setRotation( n:Number ):void
		{
			super.setRotation( n );
			this._calcWidthAndHeight();
		}
		
		/**********************************************************************/
		
		// calculates the width and height of the Btn
		private function _calcWidthAndHeight():void
		{
			var rect:CCRect = this.boundingBox();
			this.m_width	= rect.getMaxX() - rect.getMinX();
			this.m_height	= rect.getMaxY() - rect.getMinY();
		}
		
		// called when we click on the button
		private function _onClick( id:int, x:int, y:int ):void
		{
			if( this.enabled )
				this.onBtnClick( this );
		}
		
	}
}