package gui
{
	import cocos2d.CCPoint;
	
	import Loom.Animation.Tween;
	
	import constants.GameConstants;
	import constants.Resources;
	
	/**
	 * The graphics for highlighting a card
	 */
	public class CardHighlight extends Image
	{
		
		/**
		 * Creates a new CardHighlight object
		 */
		public function CardHighlight()
		{
			super( Resources.ATLAS_SPRITES, Resources.SPRITE_CARD_HIGHLIGHT );
			
			// set our anchor point to the bottom left
			this.setAnchorPoint( new CCPoint );
		}
		
		/**
		 * Destroys the CardHighlight and clears it for garbage collection
		 */
		override public function destroy():void
		{
			Tween.killTweensOf( this );
		}
		
		/**
		 * Animates the card moving a specific coord
		 * @param x The x value to move to
		 * @param y The y value to move to
		 * @param isStraight Are we straight?
		 */
		public function moveTo( x:int, y:int, isStraight:Boolean ):void
		{			
			// remove any tweens
			Tween.killTweensOf( this );
			
			// set our position
			this.x 		= x;
			this.y 		= y;
			this.alpha	= 1.0;
			
			// are we straight
			if( isStraight )
			{	
				this.setSkewX( 0.0 );
				this.scaleY = 1.0;
			}
			else
			{
				this.setSkewX( GameConstants.TABLE_OBJS_SKEW );
				this.scaleY = GameConstants.TABLE_OBJS_SCALE;
			}
			
			// start tweening our alpha
			Tween.to( this, 0.25, { "alpha":0.25 } ).onComplete += this._onAlphaComplete;
		}
		
		/**
		 * Hide the card highlight
		 */
		public function hide():void
		{
			Tween.killTweensOf( this );
			if( this.getParent() != null )
				this.getParent().removeChild( this, false );
		}
		
		/**********************************************************************/
		
		// called when our alpha tween has finished
		private function _onAlphaComplete( t:Tween ):void
		{
			var alpha:Number = ( this.alpha == 1.0 ) ? 0.25 : 1.0;
			Tween.to( this, 0.25, { "alpha":alpha } ).onComplete += this._onAlphaComplete;
		}
	}
}