package gui
{
	import cocos2d.CCPoint;
	
	import Loom.Animation.Tween;
	import Loom.Animation.EaseType;
	
	import constants.Resources;
	
	/**
	 * The dealer button to show who's the current dealer
	 */
	public class DealerButton extends Image
	{
		
		/**********************************************************************/
		
		private var m_canvasHeight:int		= 0;	// the height for our canvas
		private var m_destPlayer:CCPoint;			// our destination for when the player is the dealer
		private var m_destOpponent:CCPoint;			// our destination for when the opponent is the dealer
		
		/**********************************************************************/
		
		/**
		 * Sets if the opponent is the dealer or not
		 */
		public function set opponentIsDealer( b:Boolean ):void
		{
			// get the destination point
			var dest:CCPoint = this.m_destOpponent;
			if( !b )
				dest = this.m_destPlayer;
				
			// check if we're already there
			if( this.x == dest.x && this.y == dest.y )
				return;
				
			// remove any previous tweens
			Tween.killTweensOf( this );
			
			// get our transition type
			var ease:EaseType 	= ( this.y == this.m_canvasHeight ) ? EaseType.EASE_OUT_BOUNCE : EaseType.EASE_OUT;
			var time:Number 	= ( ease == EaseType.EASE_OUT_BOUNCE ) ? 1.0 : 0.4;
			Tween.to( this, time, { "x":dest.x, "ease":ease } );
			Tween.to( this, time, { "y":dest.y, "ease":ease } );
		}
		
		/**********************************************************************/
		
		/**
		 * Creates a new DealerButton object
		 * @param canvasHeight The height for our canvas
		 */
		public function DealerButton( canvasHeight:int )
		{
			super( Resources.ATLAS_SPRITES, Resources.SPRITE_DEALER_BUTTON );
			this.m_canvasHeight = canvasHeight;
			
			// set our anchor point to the bottom left
			this.setAnchorPoint( new CCPoint );
			
			// set our two destination points
			this.m_destPlayer	= new CCPoint( 162.0, 10.0 );
			this.m_destOpponent	= new CCPoint( 231.0, 140.0 );
		}
		
		/**
		 * Resets the dealer button
		 */
		public function reset():void
		{
			// set our position to be the opponent point, but above the canvas so that we drop in
			this.x 		= this.m_destOpponent.x;
			this.y 		= this.m_canvasHeight;
			this.alpha	= 1.0;
		}
		
		/**
		 * Destroys the DealerButton and clears it for garbage collection
		 */
		override public function destroy():void
		{
			super.destroy();
			Tween.killTweensOf( this );
		}
		
	}
}