package gui
{
	import cocos2d.CCRect;
	import cocos2d.CCPoint;
	import UI.AtlasSprite;
	
	/**
	 * An Image class, which wraps AtlasSprite and provides some convenience methods
	 */
	public class Image extends AtlasSprite
	{
		
		/**********************************************************************/
		
		private var m_width:int 	= 0.0; // the width of the image
		private var m_height:int 	= 0.0; // the height of the image
		
		/**********************************************************************/
		
		/**
		 * The width of the image
		 */
		public function get width():int { return this.m_width; }
		
		/**
		 * The height of the image
		 */
		public function get height():int { return this.m_height; }
		
		/**
		 * The rotation for the image
		 */
		public function get rotation():Number { return this.getRotation(); }
		public function set rotation( n:Number ):void
		{
			this.setRotation( n );
		}
		
		/**
		 * Sets the x scale for the image
		 */
		override public function get scaleX():Number { return super.getScaleX(); }
		override public function set scaleX( n:Number ):void
		{
			super.setScaleX( n );
			this._calcWidthAndHeight();
		}
		
		/**
		 * Sets the y scale for the image
		 */
		override public function get scaleY():Number { return super.getScaleY(); }
		override public function set scaleY( n:Number ):void
		{
			super.setScaleY( n );
			this._calcWidthAndHeight();
		}
		
		/**
		 * Sets the scale for the image
		 */
		override public function get scale():Number { return super.getScale(); }
		override public function set scale( n:Number ):void
		{
			super.setScale( n );
			this._calcWidthAndHeight();
		}
		
		/**
		 * The alpha for the image
		 */
		public function get alpha():Number
		{
			var o:int = this.getOpacity();
			return ( o < 0 ) ? 0.0 : ( o > 255 ) ? 1.0 : o / 255.0;
		}
		public function set alpha( n:Number ):void
		{
			n = ( n < 0.0 ) ? 0.0 : ( n > 1.0 ) ? 1.0 : n;
			this.setOpacity( n * 255 );
		}
		
		/**********************************************************************/
		
		/**
		 * Creates a new Image
		 * @param atlasID The ID of the atlas texture
		 * @param texture Our texture ID
		 */
		public function Image( atlasID:String, texture:String )
		{
			super( null ); // passing texture here seems to crash the atlas
			this.atlasID = atlasID;
			this.texture = texture;
			
			// set our anchor point to the top left corner
			this.setAnchorPoint( new CCPoint( 0.0, 1.0 ) );
			
			// calculate our width and height
			this._calcWidthAndHeight();
		}
		
		/**
		 * Destroys the Image and clears it for garbage collection
		 */
		public function destroy():void
		{
			// remove us
			if( this.getParent() != null )
				this.getParent().removeChild( this, true );
				
			// remove all our children
			this.removeAllChildrenWithCleanup( true );
			
			// clear our delegates
			this.onTouchBegan		= null;
			this.onTouchMoved		= null;
			this.onTouchEnded		= null;
			this.onTouchCancelled	= null;
		}
		
		/**
		 * Sets the rotation for the image
		 */
		override public function setRotation( n:Number ):void
		{
			super.setRotation( n );
			this._calcWidthAndHeight();
		}
		
		/**********************************************************************/
		
		// calculates the width and height of the image
		private function _calcWidthAndHeight():void
		{
			var rect:CCRect = this.boundingBox();
			this.m_width	= rect.getMaxX() - rect.getMinX();
			this.m_height	= rect.getMaxY() - rect.getMinY();
		}
		
	}
}