package gui
{
	import cocos2d.ccColor3B;
	
	import Loom.Animation.Tween;
	import Loom.Animation.EaseType;
	
	import constants.Resources;
	
	/**
	 * The MsgBar that we use to show messages to the player
	 */
	public class MsgBar extends Image
	{
		
		/**********************************************************************/
		
		private var m_txt:TextField 		= null; // the textfield to show the actual speech
		private var m_canvasHeight:Number	= 0.0;	// the height of the main canvas
		
		/**********************************************************************/
		
		/**
		 * The text to display in the speech bubble
		 */
		public function set text( s:String ):void
		{
			this.m_txt.text = s;
			this.m_txt.x	= -this.m_txt.width;
		}
		
		/**********************************************************************/
		
		/**
		 * Creates a new MsgBar
		 * @param canvasHeight The height of the main canvas
		 */
		public function MsgBar( canvasHeight:Number )
		{
			super( Resources.ATLAS_SPRITES, Resources.SPRITE_MSG_BAR );
			
			// set our position
			this.m_canvasHeight	= canvasHeight;
			this.y 				= this.m_canvasHeight + this.height; // hide us to begin with
			
			// create our textfield
			this.m_txt 			= new TextField( "", Resources.FONT_CURSE, new ccColor3B( 0, 0, 0 ) );
			this.m_txt.scale	= 0.35;
			this.text			= "Hello world!";
			this.m_txt.y 		= this.height - this.m_txt.height * 0.75;
			this.addChild( this.m_txt );
		}
		
		/**
		 * Destroys the MsgBar and clears it for garbage collection
		 */
		override public function destroy():void
		{
			super.destroy();
			
			// kill any tweens
			Tween.killTweensOf( this );
			
			// destroy our properties
			this.m_txt.destroy();
			
			// clear our properties
			this.m_txt = null;
		}
		
		/**
		 * Shows the speech bubble
		 * @param text The text to show in it
		 */
		public function show( text:String ):void
		{
			this.text = text;
			
			// show the bar
			if( y > this.m_canvasHeight )
			{
				Tween.killTweensOf( this );
				Tween.to( this, 0.2, { "y":this.m_canvasHeight, "ease":EaseType.EASE_OUT } ).onComplete += this._onShowBarFinish;
			}
			else
				this._onShowBarFinish(); // just move the text in
		}
		
		/**
		 * Hides the speech bubble
		 */
		public function hide():void
		{
			// tween us out
			Tween.killTweensOf( this );
			Tween.to( this, 0.2, { "y":this.m_canvasHeight + this.height, "ease":EaseType.EASE_IN } );
		}
		
		/**********************************************************************/
		
		// called when our bar anim is finished
		private function _onShowBarFinish( t:Tween = null ):void
		{
			// get the x for our text
			var x:Number = this.width * 0.5 - this.m_txt.width * 0.5 - 10.0;
			
			// tween our text
			Tween.killTweensOf( this.m_txt );
			Tween.to( this.m_txt, 0.2, { "x":x, "ease":EaseType.EASE_OUT } ).onComplete += this._onShowTextFinish;
		}
		
		// called when the text is finished coming in
		private function _onShowTextFinish( t:Tween ):void
		{
			// give a slight movement for our text
			// get the x for our text
			var x:Number = this.width * 0.5 - this.m_txt.width * 0.5 + 10.0;
			
			// tween our text
			Tween.killTweensOf( this.m_txt );
			Tween.to( this.m_txt, 3.0, { "x":x, "ease":EaseType.LINEAR } ).onComplete += this._onScrollTextFinish;
		}
		
		// called when our text is finished scrolling
		private function _onScrollTextFinish( t:Tween ):void
		{
			// tween our text off the screen
			Tween.killTweensOf( this.m_txt );
			Tween.to( this.m_txt, 0.2, { "x":this.width, "ease":EaseType.EASE_IN } ).onComplete += this._onHideTextFinish;
		}
		
		// called when our text is finished hiding
		private function _onHideTextFinish( t:Tween ):void
		{
			this.hide();
		}
		
	}
}