package gui
{
	import cocos2d.ccColor3B;
	
	import constants.Resources;
	import gui.TextField;
	import logic.AIPlayer;

	/**
	 * The PlayerBtn class is the button that we use in the main menu
	 */
	public class PlayerBtn extends Btn
	{
		
		/**********************************************************************/
		
		private static const M_TXT_COLOUR_NORMAL:ccColor3B 		= new ccColor3B( 144, 14, 14 ); // the normal text colour
		private static const M_TXT_COLOUR_DISABLED:ccColor3B 	= new ccColor3B( 79, 79, 79 ); // the disabled text colour
		
		/**********************************************************************/
		
		private var m_aiPlayer:AIPlayer	= null;	// the ai player for this button
		private var m_buyIn:TextField 	= null; // the textfield to show the cost of the buy-in
		
		/**********************************************************************/
		
		/**
		 * The Player that this button is for
		 */
		public function get aiPlayer():AIPlayer { return this.m_aiPlayer; }
		
		/**
		 * The buy-in for this player
		 */
		public function get buyIn():int { return this.m_aiPlayer.buyIn; }
		
		/**
		 * Is the PlayerBtn enabled?
		 */
		override public function get enabled():Boolean { return this._enabled; }
		override public function set enabled( b:Boolean ):void
		{
			this._enabled = b;
			if( this._enabled )
			{
				this.upImage 	= this.m_aiPlayer.menuBtnGraphics
				this.downImage	= this.m_aiPlayer.menuBtnGraphicsDown;
				this.m_buyIn.setColor( PlayerBtn.M_TXT_COLOUR_NORMAL );
			}
			else
			{
				this.upImage	= this.m_aiPlayer.menuBtnGraphicsDisabled;
				this.downImage	= this.m_aiPlayer.menuBtnGraphicsDisabled;
				this.m_buyIn.setColor( PlayerBtn.M_TXT_COLOUR_DISABLED );
			}
		}
		
		/**********************************************************************/
		
		/**
		 * Creates a new PlayerBtn
		 * @param aiPlayer The AIPlayer that this button is for
		 */
		public function PlayerBtn( aiPlayer:AIPlayer )
		{
			super( aiPlayer.menuBtnGraphics, aiPlayer.menuBtnGraphicsDown, Resources.ATLAS_BUTTONS );
			this.m_aiPlayer = aiPlayer;
			
			// create our buyin textfield
			this.m_buyIn 		= new TextField( this.m_aiPlayer.buyIn + "", Resources.FONT_CURSE, PlayerBtn.M_TXT_COLOUR_NORMAL );
			this.m_buyIn.scale	= 0.5;
			this.m_buyIn.x 		= this.width * 0.5 - this.m_buyIn.width * 0.5;
			this.m_buyIn.y 		= this.m_buyIn.height * 2.2;
			this.addChild( this.m_buyIn );
		}
		
		/**
		 * Destroys the PlayerBtn and clears it for garbage collection
		 */
		override public function destroy():void
		{
			super.destroy();
			
			// destroy our properties
			this.m_buyIn.destroy();
			
			// clear our properties
			this.m_buyIn 	= null;
			this.m_aiPlayer	= null;
		}
		
	}
}