package gui
{
	import cocos2d.ccColor3B;
	
	import Loom.Animation.Tween;
	import Loom.Animation.EaseType;
	
	import constants.Resources;
	
	/**
	 * The SpeechBubble for the ai opponent, so we can see what they're thinking
	 */
	public class SpeechBubble extends Image
	{
		
		/**********************************************************************/
		
		private var m_txt:TextField 	= null; // the textfield to show the actual speech
		private var m_isShowing:Boolean	= false;// are we showing?
		
		/**********************************************************************/
		
		/**
		 * The text to display in the speech bubble
		 */
		public function set text( s:String ):void
		{
			this.m_txt.text = s;
			this.m_txt.x	= this.width * 0.5 - this.m_txt.width * 0.5;
		}
		
		/**
		 * The alpha for the image
		 */
		public function get alpha():Number
		{
			var o:int = this.getOpacity();
			return ( o < 0 ) ? 0.0 : ( o > 255 ) ? 1.0 : o / 255.0;
		}
		public function set alpha( n:Number ):void
		{
			n 					= ( n < 0.0 ) ? 0.0 : ( n > 1.0 ) ? 1.0 : n;
			this.m_txt.alpha	= n;
			this.setOpacity( n * 255 );
		}
		
		/**********************************************************************/
		
		/**
		 * Creates a new SpeechBubble
		 */
		public function SpeechBubble()
		{
			super( Resources.ATLAS_SPRITES, Resources.SPRITE_SPEECH_BUBBLE );
			
			// create our textfield
			this.m_txt 			= new TextField( "", Resources.FONT_CURSE, new ccColor3B( 0, 0, 0 ) );
			this.m_txt.scale	= 0.5;
			this.text			= "Hello world!";
			this.m_txt.y 		= this.height - this.m_txt.height * 0.75;
			this.addChild( this.m_txt );
			
			// hide us to begin with
			this.alpha = 0.0;
		}
		
		/**
		 * Destroys the SpeechBubble and clears it for garbage collection
		 */
		override public function destroy():void
		{
			super.destroy();
			
			// kill any tweens
			Tween.killTweensOf( this );
			
			// destroy our properties
			this.m_txt.destroy();
			
			// clear our properties
			this.m_txt = null;
		}
		
		/**
		 * Shows the speech bubble
		 * @param text The text to show in it
		 */
		public function show( text:String ):void
		{
			// set our text
			this.m_isShowing	= true;
			this.text 			= text;
			if( this.alpha >= 1.0 )
				return;
			
			// kill any previous tweens
			Tween.killTweensOf( this );
			Tween.to( this, 0.1, { "alpha":1.0, "ease":EaseType.EASE_OUT } );
		}
		
		/**
		 * Hides the speech bubble
		 */
		public function hide():void
		{
			if( this.alpha <= 0.0 && !this.m_isShowing )
				return;
			this.m_isShowing = false;
				
			// tween us out (don't kill any previous tweens in case it's a show() autoHide situation)
			Tween.to( this, 0.1, { "alpha":0.0, "ease":EaseType.EASE_IN, "delay":1.0 } );
		}
		
	}
}