package gui
{	
	import cocos2d.ccColor3B;
	
	import constants.Resources;
	
	/**
	 * A text button class, which wraps Btn and provides some convenience methods
	 */
	public class TextBtn extends Btn
	{
		
		/**********************************************************************/
		
		private var m_txt:TextField = null; // the textfield for our text
		
		/**********************************************************************/
		
		/**
		 * The text for this button
		 */
		public function get text():String { return this.m_txt.text; }
		public function set text( s:String ):void
		{
			this.m_txt.text = s;
		}
		
		/**
		 * The colour for the text for this button
		 */
		public function get textColour():ccColor3B { return this.m_txt.textColour; }
		public function set textColour( c:ccColor3B ):void
		{
			this.m_txt.textColour = c;
		}
		
		/**
		 * Is the TextBtn enabled?
		 */
		override public function get enabled():Boolean { return this._enabled; }
		override public function set enabled( b:Boolean ):void
		{
			this._enabled 		= b;
			this.alpha			= ( this._enabled ) ? 1.0 : 0.5;
			this.m_txt.alpha	= ( this._enabled ) ? 1.0 : 0.5;
		}
		
		/**********************************************************************/
		
		/**
		 * Creates a new TxtBtn
		 * @param text The text for the button
		 * @param upImage The image to use for the up state of the button
		 * @param downImage The image to use for the down state of the button
		 * @param atlasID The ID of the atlas texture
		 */
		public function TextBtn( text:String, upImage:String = null, downImage:String = null, atlasID:String = null )
		{
			super( upImage, downImage, atlasID );
			
			// create our textfield
			this.m_txt 			= new TextField( text, Resources.FONT_CURSE, new ccColor3B( 0, 0, 0 ) );
			this.m_txt.scale	= 0.4;
			this.m_txt.x		= 15;
			this.m_txt.y		= int( this.height * 0.5 + this.m_txt.height * 0.5 + 8.0 ); // +magic as the textfield bounderies aren't great
			this.addChild( this.m_txt );
			
			// set our text
			this.text = text;
		}
		
		/**
		 * Destroys the Btn and clears it for garbage collection
		 */
		override public function destroy():void
		{
			super.destroy();
			
			// destroy our text
			this.m_txt.destroy();
			
			// clear our properties
			this.m_txt = null;
		}
		
	}
}