package gui
{
	import cocos2d.CCRect;
	import cocos2d.CCPoint;
	import cocos2d.ccColor3B;
	import UI.Label;
	
	/**
	 * An TextField class, which wraps Label and provides some convenience methods
	 */
	public class TextField extends Label
	{
		
		/**********************************************************************/
		
		private var m_width:int 	= 0.0; // the width of the TextField
		private var m_height:int 	= 0.0; // the height of the TextField
		
		/**********************************************************************/
		
		/**
		 * The width of the TextField
		 */
		public function get width():int { return this.m_width; }
		
		/**
		 * The height of the TextField
		 */
		public function get height():int { return this.m_height; }
		
		/**
		 * Sets the rotation for the TextField
		 */
		public function get rotation():Number { return this.getRotation(); }
		
		/**
		 * Sets the x scale for the TextField
		 */
		override public function get scaleX():Number { return super.getScaleX(); }
		override public function set scaleX( n:Number ):void
		{
			super.setScaleX( n );
			this._calcWidthAndHeight();
		}
		
		/**
		 * Sets the y scale for the TextField
		 */
		override public function get scaleY():Number { return super.getScaleY(); }
		override public function set scaleY( n:Number ):void
		{
			super.setScaleY( n );
			this._calcWidthAndHeight();
		}
		
		/**
		 * Sets the scale for the TextField
		 */
		override public function get scale():Number { return super.getScale(); }
		override public function set scale( n:Number ):void
		{
			super.setScale( n );
			this._calcWidthAndHeight();
		}
		
		/**
		 * Sets the text for the TextField
		 */
		override public function get text():String{ return this._text; }
		override public function set text( s:String ):void
		{
			// we can't just call super.text here as it throws an error, so re-implement it
			this._text = s;
			if(fontFile)
				setString(_text);
			this._calcWidthAndHeight();
		}
		
		/**
		 * The colour for the text in our textfield
		 */
		public function get textColour():ccColor3B { return this.getColor(); }
		public function set textColour( c:ccColor3B ):void
		{
			this.setColor( c );
		}
		
		/**
		 * The alpha for the TextField
		 */
		public function get alpha():Number
		{
			var o:int = this.getOpacity();
			return ( o < 0 ) ? 0.0 : ( o > 255 ) ? 1.0 : o / 255.0;
		}
		public function set alpha( n:Number ):void
		{
			n = ( n < 0.0 ) ? 0.0 : ( n > 1.0 ) ? 1.0 : n;
			this.setOpacity( n * 255 );
		}
		
		/**********************************************************************/
		
		/**
		 * Creates a new TextField
		 * @param text The text to display
		 * @param fontFile The font file for us
		 */
		public function TextField( text:String, fontFile:String, colour:ccColor3B = null )
		{
			super( fontFile ); // passing texture here seems to crash the atlas
			this.text = text;
			if( colour != null )
				this.setColor( colour );
			
			// set our anchor point to the top left corner
			this.setAnchorPoint( new CCPoint( 0.0, 1.0 ) );
			
			// calculate our width and height
			this._calcWidthAndHeight();
		}
		
		/**
		 * Destroys the TextField and clears it for garbage collection
		 */
		public function destroy():void
		{
			// remove us
			if( this.getParent() != null )
				this.getParent().removeChild( this, true );
				
			// remove all our children
			this.removeAllChildrenWithCleanup( true );
		}
		
		/**
		 * Sets the rotation for the TextField
		 */
		override public function setRotation( n:Number ):void
		{
			super.setRotation( n );
			this._calcWidthAndHeight();
		}
		
		/**********************************************************************/
		
		// calculates the width and height of the TextField
		private function _calcWidthAndHeight():void
		{
			var rect:CCRect = this.boundingBox();
			this.m_width	= rect.getMaxX() - rect.getMinX();
			this.m_height	= rect.getMaxY() - rect.getMinY();
		}
		
	}
}