package gui.popups
{
	import cocos2d.ccColor3B;
	import cocos2d.CCPoint;
	
	import constants.Resources;
	import gui.TextField;
	import logic.MainPlayer;
	
	/**
	 * The popup shown at the end of the match, when we win or lose against an opponent
	 */
	public class PopupWinLose extends Popup
	{
		
		/**********************************************************************/
		
		private var m_txtTitleStats:TextField	= null;	// the title for the stats
		private var m_txtTitleHands:TextField	= null;	// the title for the number of hands that we've played
		private var m_txtTitleBluffs:TextField	= null;	// the title for the number of bluffs we've done
		private var m_txtTitleAllIns:TextField	= null;	// the title for the number of all-ins we've done
		private var m_txtTitleMoney:TextField	= null;	// the title for the amount of money that we've won/lost
		private var m_txtTitleCharity:TextField	= null;	// the title for the number of times we've received charity
		private var m_txtHands:TextField		= null;	// the number of hands we've played
		private var m_txtBluffs:TextField		= null;	// the number of bluffs we've done
		private var m_txtAllIns:TextField		= null;	// the number of all-ins we've done
		private var m_txtMoney:TextField		= null;	// the amount of money we've won/lost
		private var m_txtCharity:TextField		= null;	// the number of times we've received charity
		private var m_titlePos:CCPoint;					// the center point for the title pos (struct so we can't assign null)
		private var m_titleWinColour:ccColor3B;			// the title colour for when we win (struct so we can't assign null)
		private var m_titleLoseColour:ccColor3B;		// the title colour for when we lose (struct so we can't assign null)
		
		/**********************************************************************/
		
		/**
		 * Creates a new PopupWinLose
		 * @param canvasWidth The width of the canvas
		 * @param canvasHeight The height of the canavs
		 */
		public function PopupWinLose( canvasWidth:Number, canvasHeight:Number )
		{
			super( Resources.ATLAS_SPRITES, Resources.SPRITE_POPUP_WIN_LOSE, canvasWidth, canvasHeight );
			
			// set our center position for our title
			this.m_titlePos 		= new CCPoint( 180.0, 315.0 );
			this.m_titleWinColour	= new ccColor3B( 0, 100, 0 );
			this.m_titleLoseColour	= new ccColor3B( 100, 0, 0 );
			
			// create our textfields
			var colour:ccColor3B	= new ccColor3B( 0, 0, 0 );
			this.m_txtTitleStats 	= new TextField( "Stats so far:", Resources.FONT_CURSE, new ccColor3B( 0, 0, 100 ) );
			this.m_txtTitleHands 	= new TextField( "Num hands:", Resources.FONT_CURSE, colour );
			this.m_txtTitleBluffs 	= new TextField( "Num bluffs:", Resources.FONT_CURSE, colour );
			this.m_txtTitleAllIns 	= new TextField( "Num all-ins:", Resources.FONT_CURSE, colour );
			this.m_txtTitleMoney 	= new TextField( "Money (W/L):", Resources.FONT_CURSE, colour );
			this.m_txtTitleCharity 	= new TextField( "Num charity:", Resources.FONT_CURSE, colour );
			this.m_txtHands 		= new TextField( "0", Resources.FONT_CURSE, colour );
			this.m_txtBluffs 		= new TextField( "0", Resources.FONT_CURSE, colour );
			this.m_txtAllIns 		= new TextField( "0", Resources.FONT_CURSE, colour );
			this.m_txtMoney 		= new TextField( "0", Resources.FONT_CURSE, colour );
			this.m_txtCharity 		= new TextField( "0", Resources.FONT_CURSE, colour );
			
			// set the scales
			this.m_txtTitleStats.scale		= 0.25;
			this.m_txtTitleHands.scale		= 0.25;
			this.m_txtTitleBluffs.scale		= 0.25;
			this.m_txtTitleAllIns.scale		= 0.25;
			this.m_txtTitleMoney.scale		= 0.25;
			this.m_txtTitleCharity.scale	= 0.25;
			this.m_txtHands.scale			= 0.25;
			this.m_txtBluffs.scale			= 0.25;
			this.m_txtAllIns.scale			= 0.25;
			this.m_txtMoney.scale			= 0.25;
			this.m_txtCharity.scale			= 0.25;
			
			// set the x
			this.m_txtTitleStats.x		= 50.0;
			this.m_txtTitleHands.x		= 60.0;
			this.m_txtTitleBluffs.x		= 60.0;
			this.m_txtTitleAllIns.x		= 60.0;
			this.m_txtTitleMoney.x		= 60.0;
			this.m_txtTitleCharity.x	= 60.0;
			this.m_txtHands.x			= 180.0;
			this.m_txtBluffs.x			= 180.0;
			this.m_txtAllIns.x			= 180.0;
			this.m_txtMoney.x			= 180.0;
			this.m_txtCharity.x			= 180.0;
			
			// set the y
			var padding:int				= 10;
			this.m_txtTitle.y			= this.m_titlePos.y;
			this.m_txtTitleStats.y		= 250.0;
			this.m_txtTitleHands.y		= this.m_txtTitleStats.y - this.m_txtTitleStats.height - padding;
			this.m_txtTitleBluffs.y		= this.m_txtTitleHands.y - this.m_txtTitleHands.height - padding;
			this.m_txtTitleAllIns.y		= this.m_txtTitleBluffs.y - this.m_txtTitleBluffs.height - padding;
			this.m_txtTitleMoney.y		= this.m_txtTitleAllIns.y - this.m_txtTitleAllIns.height - padding;
			this.m_txtTitleCharity.y	= this.m_txtTitleMoney.y - this.m_txtTitleMoney.height - padding;
			this.m_txtHands.y			= this.m_txtTitleHands.y;
			this.m_txtBluffs.y			= this.m_txtTitleBluffs.y;
			this.m_txtAllIns.y			= this.m_txtTitleAllIns.y;
			this.m_txtMoney.y			= this.m_txtTitleMoney.y;
			this.m_txtCharity.y			= this.m_txtTitleCharity.y;
			
			// add them all
			this.addChild( this.m_txtTitleStats );
			this.addChild( this.m_txtTitleHands );
			this.addChild( this.m_txtTitleBluffs );
			this.addChild( this.m_txtTitleAllIns );
			this.addChild( this.m_txtTitleMoney );
			this.addChild( this.m_txtTitleCharity );
			this.addChild( this.m_txtHands );
			this.addChild( this.m_txtBluffs );
			this.addChild( this.m_txtAllIns );
			this.addChild( this.m_txtMoney );
			this.addChild( this.m_txtCharity );
		}
		
		/**
		 * Destroys the PopupWinLose and clears it for garbage collection
		 */
		override public function destroy():void
		{
			super.destroy();
			
			// destroy our objects
			this.m_txtTitleStats.destroy();
			this.m_txtTitleHands.destroy();
			this.m_txtTitleBluffs.destroy();
			this.m_txtTitleAllIns.destroy();
			this.m_txtTitleMoney.destroy();
			this.m_txtTitleCharity.destroy();
			this.m_txtHands.destroy();
			this.m_txtBluffs.destroy();
			this.m_txtAllIns.destroy();
			this.m_txtMoney.destroy();
			this.m_txtCharity.destroy();
			
			// null our properties
			this.m_txtTitleStats	= null;
			this.m_txtTitleHands	= null;
			this.m_txtTitleBluffs	= null;
			this.m_txtTitleAllIns	= null;
			this.m_txtTitleMoney	= null;
			this.m_txtTitleCharity	= null;
			this.m_txtHands			= null;
			this.m_txtBluffs		= null;
			this.m_txtAllIns		= null;
			this.m_txtMoney			= null;
			this.m_txtCharity		= null;
		}
		
		/**
		 * Shows the PopupWinLose with the player's stats
		 * @param player The main player
		 * @param didWin Did we win
		 */
		public function showPlayerStats( player:MainPlayer, didWin:Boolean ):void
		{			
			// set our title
			this.m_txtTitle.text 	= ( didWin ) ? "You win!" : "You lose :(";
			this.m_txtTitle.x		= this.m_titlePos.x - this.m_txtTitle.width * 0.5;
			if( didWin )
				this.m_txtTitle.textColour = this.m_titleWinColour;
			else
				this.m_txtTitle.textColour = this.m_titleLoseColour;
			
			// set our hand stats
			var pc:int				= ( player.statsNumHands > 0 ) ? int( ( player.statsNumHandsWon / player.statsNumHands ) * 100 + 0.5 ) : 0;
			this.m_txtHands.text 	= player.statsNumHands + " (won " + player.statsNumHandsWon + " - " + pc + "%)";
			
			// set our bluff stats
			pc						= ( player.statsNumBluffs > 0 ) ? int( ( player.statsNumBluffsWon / player.statsNumBluffs ) * 100 + 0.5 ) : 0;
			this.m_txtBluffs.text	= player.statsNumBluffs + " (worked " + player.statsNumBluffsWon + " - " + pc + "%)";
			
			// set our all in stats
			pc						= ( player.statsNumAllIns > 0 ) ? int( ( player.statsNumAllInsWon / player.statsNumAllIns ) * 100 + 0.5 ) : 0;
			this.m_txtAllIns.text	= player.statsNumAllIns + " (won " + player.statsNumAllInsWon + " - " + pc + "%)";
			
			// set our money
			this.m_txtMoney.text = player.statsCashWon + "/" + player.statsCashLost;
			
			// set our charity
			this.m_txtCharity.text = player.statsNumCharity + "";
			
			// show us
			this.show();
		}
		
	}
}