package logic
{
	import enums.CardDealDest;
	import enums.CardValue;
	import enums.CardSuit;
	
	/**
	 * Define a delegate so we can add callbacks to the card
	 */
	public delegate CardCallback():void;
	
	/**
	 * A card in the game
	 */
	public class Card
	{
		
		/**********************************************************************/
		
		/**
		 * Called when we should reveal the card. It should take no parameters
		 */
		public var onReveal:CardCallback = null;
		
		/**
		 * The name for the graphics for this card
		 */
		public var graphicsName:String = null;
		
		/**
		 * The destination of this card when dealt
		 */
		public var dest:CardDealDest = null;
		
		/**********************************************************************/
		
		private var m_value:CardValue 	= null;	// the value of the card
		private var m_suit:CardSuit		= null;	// the suit of the card
		
		/**********************************************************************/
		
		/**
		 * The value of the card
		 */
		public function get value():CardValue { return this.m_value; }
		
		/** 
		 * The suit of the card
		 */
		public function get suit():CardSuit { return this.m_suit; }
		
		/**
		 * Returns the value of this card as a String
		 */
		public function get valueString():String { return this._getValueString( this.m_value, false ); }
		
		/**
		 * Returns the values of the card as a plural String
		 */
		public function get valuePluralString():String
		{
			var str:String 	= this.valueString;
			str				+= ( this.m_value == CardValue.SIX ) ? "es" : "s";
			return str;
		}
		
		/**
		 * Returns the suit of this card as a String
		 */
		public function get suitString():String { return this._getSuitString( this.m_suit, false ); }
		
		/**********************************************************************/
		
		/**
		 * Creates a new Card
		 * @param value The value of the card
		 * @param suit The suit of the card
		 */
		public function Card( value:CardValue, suit:CardSuit )
		{
			this.m_value 	= value;
			this.m_suit		= suit;
			
			// get our graphics, which are in the form two_clubs
			this.graphicsName = this._getValueString( this.m_value ) + "_" + this._getSuitString( this.m_suit );
		}
		
		/**
		 * Destroys the Card and clears it for garbage collection
		 */
		public function destroy():void
		{
			this.onReveal	= null;
			this.dest		= null;
			this.m_value 	= null;
			this.m_suit		= null;
		}
		
		/**
		 * Reveal the card so we can see what it is
		 */
		public function reveal():void
		{
			this.onReveal();
		}
		
		/** 
		 * Return the String version of the card
		 */
		public function toString():String
		{
			return "[Card " + this._getValueString( this.m_value, true ) + "_" + this._getSuitString( this.m_suit, true ) + "]";
		}
		
		/**********************************************************************/
		
		// returns a CardValue enum as a string
		private function _getValueString( value:CardValue, short:Boolean = false ):String
		{
			if( value == CardValue.TWO ) return ( short ) ? "2" : "Two";
			else if( value == CardValue.THREE ) return ( short ) ? "3" : "Three";
			else if( value == CardValue.FOUR ) return ( short ) ? "4" : "Four";
			else if( value == CardValue.FIVE ) return ( short ) ? "5" : "Five";
			else if( value == CardValue.SIX ) return ( short ) ? "6" : "Six";
			else if( value == CardValue.SEVEN ) return ( short ) ? "7" : "Seven";
			else if( value == CardValue.EIGHT ) return ( short ) ? "8" : "Eight";
			else if( value == CardValue.NINE ) return ( short ) ? "9" : "Nine";
			else if( value == CardValue.TEN ) return ( short ) ? "10" : "Ten";
			else if( value == CardValue.JACK ) return ( short ) ? "J" : "Jack";
			else if( value == CardValue.QUEEN ) return ( short ) ? "Q" : "Queen";
			else if( value == CardValue.KING ) return ( short ) ? "K" : "King";
			else if( value == CardValue.ACE ) return ( short ) ? "A" : "Ace";
			
			// couldn't find it
			Console.print( "[Card] ERROR: Unknown CardValue '" + value + "' when getting the string" );
			return "";
		}
		
		// returns a CardSuit enum as a String
		private function _getSuitString( suit:CardSuit, short:Boolean = false ):String
		{
			if( suit == CardSuit.CLUBS ) return ( short ) ? "C" : "Clubs";
			else if( suit == CardSuit.DIAMONDS ) return ( short ) ? "D" : "Diamonds";
			else if( suit == CardSuit.SPADES ) return ( short ) ? "S" : "Spades";
			else if( suit == CardSuit.HEARTS ) return ( short ) ? "H" : "Hearts";
			
			// couldn't find it
			Console.print( "[Card] ERROR: Unknown CardSuit '" + suit + "' when getting the string" );
			return "";
		}
		
	}
}