package logic
{
	import cocos2d.CCUserDefault;
	
	/**
	 * The main player class, where we store their settings etc
	 */
	public class MainPlayer extends Player
	{
		
		/**********************************************************************/
		
		private static const KEY_TOTAL_MONEY:String 			= "total_money";			// the persistence key for the player's total num
		private static const KEY_STATS_NUM_HANDS:String 		= "stats_num_hands";		// the persistence key for the number of hands that they've played
		private static const KEY_STATS_NUM_HANDS_WON:String 	= "stats_num_hands_won";	// the persistence key for the number of hands that they've won
		private static const KEY_STATS_NUM_BLUFFS:String 		= "stats_num_bluffs";		// the persistence key for the number of bluffs that they've done
		private static const KEY_STATS_NUM_BLUFFS_WON:String 	= "stats_num_bluffs_won";	// the persistence key for the number of bluffs that they've won
		private static const KEY_STATS_NUM_ALL_INS:String 		= "stats_num_all_ins";		// the persistence key for the number of all-ins they've done
		private static const KEY_STATS_NUM_ALL_INS_WON:String 	= "stats_num_all_ins_won";	// the persistence key for the number of all-ins they've won
		private static const KEY_STATS_CASH_WON:String 			= "stats_cash_won";			// the persistence key for the amount of cash they've won
		private static const KEY_STATS_CASH_LOST:String 		= "stats_cash_lost";		// the persistence key for the amount of cash they've lost
		private static const KEY_STATS_NUM_CHARITY:String 		= "stats_num_charity";		// the persistence key for the number of times they've received charity
		
		/**********************************************************************/
		
		private var m_lso:CCUserDefault		= null;	// the persistence object
		private var m_totalMoney:int 		= 0;	// the player's total num
		private var m_statsNumHands:int 	= 0;	// the number of hands that they've played
		private var m_statsNumHandsWon:int 	= 0;	// the number of hands that they've won
		private var m_statsNumBluffs:int 	= 0;	// the number of bluffs that they've done
		private var m_statsNumBluffsWon:int = 0;	// the number of bluffs that they've won
		private var m_statsNumAllIns:int 	= 0;	// the number of all-ins they've done
		private var m_statsNumAllInsWon:int = 0;	// the number of all-ins they've won
		private var m_statsCashWon:int 		= 0;	// the amount of cash they've won
		private var m_statsCashLost:int 	= 0;	// the amount of cash they've lost
		private var m_statsNumCharity:int 	= 0;	// the number of times they've received charity
		
		/**********************************************************************/
		
		/**
		 * The player's total money level
		 */
		public function get totalMoney():int { return this.m_totalMoney; }
		public function set totalMoney( i:int ):void
		{
			this.m_totalMoney = ( i < 0 ) ? 0 : i;
			this.m_lso.setIntegerForKey( MainPlayer.KEY_TOTAL_MONEY, this.m_totalMoney ); // persist it
		}
		
		/**
		 * The number of hands that the player has played
		 */
		public function get statsNumHands():int { return this.m_statsNumHands; }
		public function set statsNumHands( i:int ):void
		{
			this.m_statsNumHands = ( i < 0 ) ? 0 : i ;
			this.m_lso.setIntegerForKey( MainPlayer.KEY_STATS_NUM_HANDS, this.m_statsNumHands ); // persist it
		}
		
		/**
		 * The number of hands that the player has won
		 */
		public function get statsNumHandsWon():int { return this.m_statsNumHandsWon; }
		public function set statsNumHandsWon( i:int ):void
		{
			this.m_statsNumHandsWon = ( i < 0 ) ? 0 : i;
			this.m_lso.setIntegerForKey( MainPlayer.KEY_STATS_NUM_HANDS_WON, this.m_statsNumHandsWon ); // persist it
		}
		
		/**
		 * The number of bluffs that the player has played
		 */
		public function get statsNumBluffs():int { return this.m_statsNumBluffs; }
		public function set statsNumBluffs( i:int ):void
		{
			this.m_statsNumBluffs = ( i < 0 ) ? 0 : i;
			this.m_lso.setIntegerForKey( MainPlayer.KEY_STATS_NUM_BLUFFS, this.m_statsNumBluffs ); // persist it
		}
		
		/**
		 * The number of bluffs that the player has won
		 */
		public function get statsNumBluffsWon():int { return this.m_statsNumBluffsWon; }
		public function set statsNumBluffsWon( i:int ):void
		{
			this.m_statsNumBluffsWon = ( i < 0 ) ? 0 : i;
			this.m_lso.setIntegerForKey( MainPlayer.KEY_STATS_NUM_BLUFFS_WON, this.m_statsNumBluffsWon ); // persist it
		}
		
		/**
		 * The number of times the player has went all in
		 */
		public function get statsNumAllIns():int { return this.m_statsNumAllIns; }
		public function set statsNumAllIns( i:int ):void
		{
			this.m_statsNumAllIns = ( i < 0 ) ? 0 : i;
			this.m_lso.setIntegerForKey( MainPlayer.KEY_STATS_NUM_ALL_INS, this.m_statsNumAllIns ); // persist it
		}
		
		/**
		 * The number of times the player has went all in and won
		 */
		public function get statsNumAllInsWon():int { return this.m_statsNumAllInsWon; }
		public function set statsNumAllInsWon( i:int ):void
		{
			this.m_statsNumAllInsWon = ( i < 0 ) ? 0 : i;
			this.m_lso.setIntegerForKey( MainPlayer.KEY_STATS_NUM_ALL_INS_WON, this.m_statsNumAllInsWon ); // persist it
		}
		
		/**
		 * The amount of cash that the player has won
		 */
		public function get statsCashWon():int { return this.m_statsCashWon; }
		public function set statsCashWon( i:int ):void
		{
			this.m_statsCashWon = ( i < 0 ) ? 0 : i;
			this.m_lso.setIntegerForKey( MainPlayer.KEY_STATS_CASH_WON, this.m_statsCashWon ); // persist it
		}
		
		/**
		 * The amount of cash that the player has lost
		 */
		public function get statsCashLost():int { return this.m_statsCashLost; }
		public function set statsCashLost( i:int ):void
		{
			this.m_statsCashLost = ( i < 0 ) ? 0 : i;
			this.m_lso.setIntegerForKey( MainPlayer.KEY_STATS_CASH_LOST, this.m_statsCashLost ); // persist it
		}
		
		/**
		 * The number of times we've had to give the player money as they've lost everything
		 */
		public function get statsNumCharity():int { return this.m_statsNumCharity; }
		public function set statsNumCharity( i:int ):void
		{
			this.m_statsNumCharity = ( i < 0 ) ? 0 : i;
			this.m_lso.setIntegerForKey( MainPlayer.KEY_STATS_NUM_CHARITY, this.m_statsNumCharity ); // persist it
		}
		
		/**
		 * Are we all-in?
		 */
		override public function get isAllIn():Boolean { return this.m_isAllIn; }
		override public function set isAllIn( b:Boolean ):void
		{
			this.m_isAllIn = b;
			if( this.m_isAllIn )
				this.statsNumAllIns += 1;
		}
		
		/**********************************************************************/
		
		/**
		 * Creates a new MainPlayer
		 */
		public function MainPlayer()
		{
			super();
			
			// get the persistence object
			this.m_lso = CCUserDefault.sharedUserDefault();
			
			// look for our initial values
			this.m_totalMoney 			= this.m_lso.getIntegerForKey( MainPlayer.KEY_TOTAL_MONEY );
			this.m_statsNumHands 		= this.m_lso.getIntegerForKey( MainPlayer.KEY_STATS_NUM_HANDS );
			this.m_statsNumHandsWon 	= this.m_lso.getIntegerForKey( MainPlayer.KEY_STATS_NUM_HANDS_WON );
			this.m_statsNumBluffs 		= this.m_lso.getIntegerForKey( MainPlayer.KEY_STATS_NUM_BLUFFS );
			this.m_statsNumBluffsWon 	= this.m_lso.getIntegerForKey( MainPlayer.KEY_STATS_NUM_BLUFFS_WON );
			this.m_statsNumAllIns 		= this.m_lso.getIntegerForKey( MainPlayer.KEY_STATS_NUM_ALL_INS );
			this.m_statsNumAllInsWon 	= this.m_lso.getIntegerForKey( MainPlayer.KEY_STATS_NUM_ALL_INS_WON );
			this.m_statsCashWon 		= this.m_lso.getIntegerForKey( MainPlayer.KEY_STATS_CASH_WON );
			this.m_statsCashLost 		= this.m_lso.getIntegerForKey( MainPlayer.KEY_STATS_CASH_LOST );
			this.m_statsNumCharity 		= this.m_lso.getIntegerForKey( MainPlayer.KEY_STATS_NUM_CHARITY );
		}
		
		/**
		 * Clears all the stats saved on the player
		 */
		public function clearStats():void
		{
			CCUserDefault.purgeSharedUserDefault();
		}
		
		/**
		 * The player wins the hand
		 * @param opponentFolded Did our opponent fold?
		 * @param splitPot Was this a split pot?
		 */
		override public function winHand( opponentFolded:Boolean, splitPot:Boolean ):void
		{
			this.statsNumHandsWon += 1; // up our stats
			if( this.m_isAllIn )
				this.statsNumAllInsWon += 1; // we won on an all-in
			super.winHand( opponentFolded, splitPot );
		}
		
		/**
		 * The String version of the MainPlayer
		 */
		public function toString():String
		{
			return "[MainPlayer money: " + this.money + "/" + this.totalMoney + "]";
		}
		
	}
}