package logic
{
	import System.XML.XMLDocument;
	import System.XML.XMLError;
	import System.XML.XMLElement;
	import System.XML.XMLNode;

	/**
	 * The player manager controls the players that we play against
	 */
	public class PlayerManager
	{
		
		/**********************************************************************/
		
		private var m_players:Vector.<AIPlayer> = null; // the players in the game
		
		/**********************************************************************/
		
		/**
		 * The number of players that we can play against
		 */
		public function get numPlayers():int { return this.m_players.length; }
		
		/**********************************************************************/
		
		/**
		 * Creates a new PlayerManager
		 */
		public function PlayerManager()
		{
			this.m_players = new Vector.<AIPlayer>();
		}
		
		/**
		 * Destroys the PlayerManager and clears it for garbage collection
		 */
		public function destroy():void
		{
			// destroy all our players
			var len:int = this.m_players.length;
			for( var i:int = 0; i < len; i++ )
				this.m_players[i].destroy();
				
			// null our properties
			this.m_players = null;
		}
		
		/**
		 * Creates the players from an XML file
		 */
		public function createFromXML( xmlURL:String ):void
		{
			// load our doc
			var xmlDoc:XMLDocument 	= new XMLDocument();
			var errorID:Number		= xmlDoc.loadFile( xmlURL );
			if( errorID != XMLError.XML_NO_ERROR )
			{
				Console.print( "[PlayerManager] ERROR: Couldn't load the player data from '" + xmlURL + "', error id: " + errorID );
				return;
			}
				
			// get the root element
			var root:XMLElement = xmlDoc.rootElement();
			
			// go through and create our players
			var px:XMLNode = root.firstChild();
			while( px != null )
			{
				// create our player and read our data
				var player:AIPlayer = new AIPlayer;
				player.fromXML( px );
				
				// add it to the vector and get the next one
				this.m_players.push( player );
				px = px.nextSibling();
			}
		}
		
		/**
		 * Returns a player by name
		 * @param name The name of the player we're looking for
		 * @return The AIPlayer, or null if we can't find one with that name
		 */
		public function getPlayerByName( name:String ):AIPlayer
		{
			var len:int = this.m_players.length;
			for( var i:int = 0; i < len; i++ )
			{
				if( this.m_players[i].name == name )
					return this.m_players[i];
			}
			
			// couldn't find it
			Console.print( "[PlayerManager] ERROR: Couldn't find the player with the name '" + name + "'" );
			return null;
		}
		
		/**
		 * Returns a player by index
		 * @param index The index of the Player that we're looking for
		 * @return The AIPlayer, or null if the index is no good
		 */
		public function getPlayerByIndex( index:int ):AIPlayer
		{
			// check our index
			if( index < 0 || index >= this.m_players.length )
			{
				Console.print( "[PlayerManager] ERROR: Couldn't find the player at index " + index + " because that index is out of bounds" );
				return null;
			}
			
			// return our player
			return this.m_players[index];
		}
		
	}
}