package logic.animations
{
	import Loom.Animation.Tween;
	
	import gui.PlayerGraphics;
	import logic.AIPlayer;
	
	/**
	 * Define a delegate so we can add callbacks to the animation
	 */
	public delegate AnimationCallback():void;
	
	/**
	 * The base animation class, that the other animations will extends
	 */
	public class Animation
	{
		
		/**********************************************************************/
		
		/**
		 * Called when the animation has finished. It should take no parameters
		 */
		public var onFinish:AnimationCallback = null;
		
		/**
		 * The name of the animation
		 */
		public var name:String = null;

		/**********************************************************************/
	
		protected var m_aiPlayer:AIPlayer		= null;	// the ai player that the graphics are for
		protected var m_graphics:PlayerGraphics = null; // the graphics that this is for
		
		/**********************************************************************/
		
		/**
		 * The AIPlayer that the graphics are for
		 */
		public function set aiPlayer( a:AIPlayer ):void
		{
			this.m_aiPlayer = a;
		}
		
		/**********************************************************************/
		
		/**
		 * Creates a new Animation
		 * @param name The name of the animation
		 * @param graphics The graphics that we're controlling in this animation
		 */
		public function Animation( name:String, graphics:PlayerGraphics )
		{
			this.name		= name;
			this.m_graphics = graphics;
		}
		
		/**
		 * Destroys the Animation
		 */
		public function destroy():void
		{
			this.onFinish	= null;
			this.m_graphics = null;
			this.m_aiPlayer	= null;
		}
		
		/**
		 * Plays the animation
		 */
		public function play():void
		{
			// to be overridden
		}
		
		/**
		 * Stops the animation. This doesn't call the onFinish delegate
		 */
		public function stop():void
		{
			// kill any tweens
			Tween.killTweensOf( this.m_graphics );
		}
		
	}
}