package logic.animations
{
	import Loom.Animation.Tween;
	import Loom.Animation.EaseType;
	
	import gui.PlayerGraphics;
	
	/**
	 * The check cards animation, which we'll play on the ai player sometimes when they're thinking
	 */
	public class AnimationCheckCards extends Animation
	{
		
		/**********************************************************************/
		
		private var m_origX:Number = 0.0; // the original x for the graphics
		private var m_origY:Number = 0.0; // the original y for the graphics
		
		/**********************************************************************/
	
		/**
		 * Creates a new Animation
		 * @param name The name of the animation
		 * @param graphics The graphics that we're controlling in this animation
		 */
		public function AnimationCheckCards( name:String, graphics:PlayerGraphics )
		{
			super( name, graphics );
		}
		
		/**
		 * Plays the check cards animation
		 */
		override function play():void
		{
			this.m_origX = this.m_graphics.x;
			this.m_origY = this.m_graphics.y;
			
			Tween.to( this.m_graphics, 0.5, { "x": this.m_graphics.x - 20.0, "y":this.m_graphics.y - 70, "ease":EaseType.EASE_OUT } ).onComplete += this._onMoveInComplete;
		}
		
		/**********************************************************************/
		
		// called when our move in part has finished
		private function _onMoveInComplete( t:Tween ):void
		{
			Tween.to( this.m_graphics, 0.5, { "y":this.m_graphics.y + 10.0, "ease":EaseType.EASE_OUT, "delay":0.5 } ).onComplete += this._onPeekComplete;
		}
		
		// called when the peek has finished
		private function _onPeekComplete( t:Tween ):void
		{
			Tween.to( this.m_graphics, 0.5, { "y":this.m_graphics.y - 10.0, "ease":EaseType.EASE_OUT, "delay":0.5 } ).onComplete += this._onPeekReturnComplete;
		}
		
		// called when our peek return has finished
		private function _onPeekReturnComplete( t:Tween ):void
		{
			Tween.to( this.m_graphics, 0.2, { "x":this.m_origX, "y":this.m_origY, "ease":EaseType.EASE_OUT, "delay":0.8 } ).onComplete += this._onReturnComplete;
		}
		
		// called when we've returned to our original position
		private function _onReturnComplete( t:Tween ):void
		{
			this.onFinish();
		}
		
	}
}