package logic.animations
{
	import Loom.Animation.Tween;
	import Loom.Animation.EaseType;
	
	import gui.PlayerGraphics;
	
	/**
	 * The win animation, which we'll play on the ai player when they win a hand
	 */
	public class AnimationWin extends Animation
	{
		
		/**********************************************************************/
	
		/**
		 * Creates a new Animation
		 * @param name The name of the animation
		 * @param graphics The graphics that we're controlling in this animation
		 */
		public function AnimationWin( name:String, graphics:PlayerGraphics )
		{
			super( name, graphics );
		}
		
		/**
		 * Plays the win animation
		 */
		override function play():void
		{
			// start by jumping up and down
			var origY:Number 	= this.m_graphics.y;
			this.m_graphics.y	+= 20.0;
			Tween.to( this.m_graphics, 1.0, { "y":origY, "ease":EaseType.EASE_OUT_BOUNCE } ).onComplete += this._onJumpComplete;
		}
		
		/**********************************************************************/
		
		// called when our jump part has finished
		private function _onJumpComplete( t:Tween ):void
		{
			Tween.to( this.m_graphics, 0.2, { "rotation":10, "ease":EaseType.EASE_OUT } ).onComplete += this._onShake1Complete;
		}
		
		// called when the first part of our shake is complete
		private function _onShake1Complete( t:Tween ):void
		{
			// get the player to talk
			this.m_aiPlayer.say( "Yeah!", true );
			Tween.to( this.m_graphics, 0.1, { "rotation":8, "ease":EaseType.EASE_OUT } ).onComplete += this._onShake2Complete;
		}
		
		// called when the first part of our shake is complete
		private function _onShake2Complete( t:Tween ):void
		{
			Tween.to( this.m_graphics, 0.1, { "rotation":10, "ease":EaseType.EASE_OUT } ).onComplete += this._onShakeComplete;
		}
				
		// called when the shake part has finished
		private function _onShakeComplete( t:Tween ):void
		{
			Tween.to( this.m_graphics, 0.5, { "rotation":0, "ease":EaseType.EASE_OUT } ).onComplete += this._onReturnComplete;
		}
		
		// called when we've returned to our original position
		private function _onReturnComplete( t:Tween ):void
		{
			this.onFinish();
		}
		
	}
}