package logic.evaluators
{
	import logic.Card;
	import logic.CardMatchResults;
	
	/**
	 * The base class that describes a evaluator for checking the hands of cards
	 */
	public class BaseEvaluator
	{
		
		/**********************************************************************/
		
		protected var m_evaluator:Evaluator = null; // the main evaluator class, that holds us
		
		/**********************************************************************/
		
		/**
		 * Creates a new BaseEvaluator
		 * @param evaluator The main Evaluator class that holds us
		 */
		public function BaseEvaluator( evaluator:Evaluator )
		{
			this.m_evaluator = evaluator;
		}
		
		/**
		 * Destroys the BaseEvaluator and clears it for garbage collection
		 */
		public function destroy():void
		{
			this.m_evaluator = null;
		}
		
		/**
		 * Verifies if there's a match in a given number of cards
		 * @param cards A list of cards to check
		 * @param matchResults The object to copy our results into
		 * @return The match results
		 */
		public function match( cards:Vector.<Card>, matchResults:CardMatchResults ):CardMatchResults
		{
			// To be overridden in subclasses
			return matchResults;
		}
		
	}
	
}