package logic.evaluators 
{
	import enums.HandRank;
	import logic.Card;
	import logic.CardMatchResults;
	
	/**
	 * Verifies if there's a flush in a given set of cards
	 */
	public class FlushEvaluator extends BaseEvaluator
	{
		 
		/**
		 * Creates a new FlushEvaluator
		 * @param evaluator The main Evaluator class, that holds us
		 */
		public function FlushEvaluator( evaluator:Evaluator )
		{
			super( evaluator );
		}
		
		/**
		 * Takes a group of cards and sees if there's a match for a flush
		 * @param cards The cards that we're trying to match
		 * @param matchResults The object to copy our results into
		 * @return The results of the match
		 */
		public function match( cards:Vector.<Card>, matchResults:CardMatchResults ):CardMatchResults
		{
			// reset the results object
			matchResults.reset();
			
			// quick check for card length
			var maxLen:int = 5;
			if ( cards.length < maxLen )
				return matchResults; // success should be false from the reset() call
				
			// sort the cards by suit
			cards.sort( this._sort );
				
			var len:int = cards.length;
			var num:int	= 1; // number of cards in a row that we have
			for ( var i:int = 1; i < len; i++ )
			{
				var card:Card 	= cards[i];		// the current card
				var other:Card 	= cards[i - 1];	// the previous card
				if ( other.suit == card.suit )
				{
					matchResults.bestHand.push( other ); // add it to our best hand
					num++;
					if ( num == maxLen )
					{
						matchResults.bestHand.push( card );
						
						// it's a match, set up the match results, and store them
						matchResults.type		= HandRank.FLUSH;
						matchResults.success	= true;
						return matchResults;
					}
				}
				else
				{
					num = 1; // not the same suit
					matchResults.bestHand.clear();
				}
			}
			
			// no match
			return matchResults; // success should be false from the reset() call
		}
		
		/*******************************************************************************************/
		
		/**
		 * Sorts 2 cards based on their suit
		 * @param a The first card
		 * @param b The second card
		 * @return If the first card is lower than the second
		 */
		private function _sort( a:Card, b:Card ):int
		{
			if ( a.suit == b.suit )
				return b.value - a.value; // sort so it's highest to lowest
			return a.suit - b.suit;
		}
		
	}

}