package logic.evaluators 
{
	import enums.HandRank;
	import logic.Card;
	import logic.CardMatchResults;
	
	/**
	 * Checks a set of cards to see if there's a full house
	 */
	public class FullHouseEvaluator extends BaseEvaluator
	{
		 
		/**
		 * Creates a new FullHouseEvaluator
		 * @param evaluator The main Evaluator class, that holds us
		 */
		public function FullHouseEvaluator( evaluator:Evaluator )
		{
			super( evaluator );
		}
		
		/**
		 * Takes a group of cards and sees if there's a match for a full house
		 * @param cards The cards that we're trying to match
		 * @param matchResults The object to copy our match results into
		 * @return The results of the match
		 */
		public function match( cards:Vector.<Card>, matchResults:CardMatchResults ):CardMatchResults
		{
			// reset our results object
			matchResults.reset();
			
			// quick out
			if( cards.length < 5 )
				return matchResults;
			
			// see if there's some trips first
			matchResults = this.m_evaluator.matchTrips( cards, matchResults );
			if ( !matchResults.success )
				return matchResults; // no trops = no full
			
			// keep a copy of the first three cards
			var bestCard1:Card = matchResults.bestHand[0];
			var bestCard2:Card = matchResults.bestHand[1];
			var bestCard3:Card = matchResults.bestHand[2];
			
			// there's the trips, now look for the pair
			matchResults = this.m_evaluator.matchPair( cards, matchResults, bestCard1.value ); // ignore the trips set
			if ( !matchResults.success )
				return matchResults; // if it didn't match the pair, this should return false
				
			// set our best hand
			matchResults.bestHand[3] = matchResults.bestHand[0]; // pair
			matchResults.bestHand[4] = matchResults.bestHand[1];
			matchResults.bestHand[0] = bestCard1; // trips
			matchResults.bestHand[1] = bestCard2;
			matchResults.bestHand[2] = bestCard3;
			
			// there's a full house, store the results (the pair) in our cache
			matchResults.type		= HandRank.FULL_HOUSE;
			matchResults.success	= true;
		
			// return our results
			return matchResults;
		}
		
	}

}