package logic.evaluators 
{
	import enums.HandRank;
	import logic.Card;
	import logic.CardMatchResults;
	
	/**
	 * Checks for the highest card in your hand
	 */
	public class HighCardEvaluator extends BaseEvaluator
	{	
		/**
		 * NOTE: this class will always return a match
		 */
		 
		/**
		 * Creates a new HighCardEvaluator
		 * @param evaluator The main Evaluator class, that holds us
		 */
		public function HighCardEvaluator( evaluator:Evaluator )
		{
			super( evaluator );
		}
		
		/**
		 * Matches the highest card in a specific set of cards
		 * @param cards The set of cards we're checking
		 * @param matchResults The object to copy our match results into
		 * @return The results of the match
		 */
		override public function match( cards:Vector.<Card>, matchResults:CardMatchResults ):CardMatchResults
		{
			// reset our match results object
			matchResults.reset();
			
			// sort the cards (so we'll always match the highest pair)
			cards.sort( this._sort );
			
			// set our results
			matchResults.type		= HandRank.HIGH_CARD;
			matchResults.success	= true;
			
			// fill our best hand
			var len:int = ( cards.length < 5 ) ? cards.length : 5;
			for( var i:int = 0; i < len; i++ )
				matchResults.bestHand.push( cards[i] );
			
			// return the results
			return matchResults;
		}
		
		/*******************************************************************************************/
		
		/**
		 * Sorts 2 cards based on their index
		 * @param a The first card
		 * @param b The second card
		 * @return If the first card is higher than the second
		 */
		private function _sort( a:Card, b:Card ):int
		{
			return b.value - a.value;
		}
		
	}

}