package logic.evaluators 
{
	import enums.CardValue;
	import enums.HandRank;
	import logic.Card;
	import logic.CardMatchResults;
	
	/**
	 * Verifies if there's a pair in a given set of cards
	 */
	public class PairEvaluator extends BaseEvaluator
	{
		
		/*******************************************************************************************/
		
		/**
		 * When checking for a pair, ignore this card
		 */
		public var ignoreCard:CardValue = null;
		
		/*******************************************************************************************/
		 
		/**
		 * Creates a new PairEvaluator
		 * @param evaluator The main Evaluator class, that holds us
		 */
		public function PairEvaluator( evaluator:Evaluator )
		{
			super( evaluator );
		}
		
		/**
		 * Takes a group of cards and sees if there's a match for a pair
		 * @param cards The cards that we're trying to match
		 * @param matchResults The object to copy our results into
		 * @return The results of the match
		 */
		override public function match( cards:Vector.<Card>, matchResults:CardMatchResults ):CardMatchResults
		{
			// reset our results object
			matchResults.reset();
			
			// sort the cards (so we'll always match the highest pair)
			cards.sort( this._sort );
				
			// check if we have a pair
			var len:int = cards.length;
			for ( var i:int = 1; i < len; i++ )
			{
				var card:Card 	= cards[i];
				var other:Card 	= cards[i - 1];
				if ( card.value == this.ignoreCard ) // if we have an ignore card and this is it, continue
					continue;
					
				// see is it a match
				if ( card.value == other.value )
				{
					// set up our best hand
					matchResults.bestHand.push( other );
					matchResults.bestHand.push( card );
					
					// our cards are sorted from lowest to highest, so go through and pick
					// the two other highest cards to make our best hand
					for( var j:int = 0; j < len; j++ )
					{
						if( cards[j].value != card.value )
						{
							matchResults.bestHand.push( cards[j] );
							if( matchResults.bestHand.length == 5 )
								break;
						}
					}
						
					// it's a match, set up the match results, and return them
					matchResults.type		= HandRank.PAIR;
					matchResults.success	= true;
					
					// return our results
					return matchResults;
				}
			}
			
			return matchResults; // success will be false as a result of the reset() call
		}
		
		/*******************************************************************************************/
		
		/**
		 * Sorts 2 cards based on their index
		 * @param a The first card
		 * @param b The second card
		 * @return If the first card is higher than the second
		 */
		private function _sort( a:Card, b:Card ):int
		{
			return b.value - a.value;
		}
		
	}

}