package logic.evaluators 
{
	import enums.HandRank;
	import logic.Card;
	import logic.CardMatchResults;
	
	/**
	 * Checks a set of cards to see if we have a poker
	 */
	public class PokerEvaluator extends BaseEvaluator
	{
		 
		/**
		 * Creates a new PokerEvaluator
		 * @param evaluator The main Evaluator class, that holds us
		 */
		public function PokerEvaluator( evaluator:Evaluator )
		{
			super( evaluator );
		}
		
		/**
		 * Takes a group of cards and sees if there's a match for a poker
		 * @param cards The cards that we're trying to match
		 * @param matchResults The object to copy our match results into
		 * @return The results of the match
		 */
		public function match( cards:Vector.<Card>, matchResults:CardMatchResults ):CardMatchResults
		{
			// reset our results object
			matchResults.reset();
			
			// quick out
			if( cards.length < 4 )
				return matchResults;
			
			// sort the cards (so we always match the highest 4)
			cards.sort( this._sort );
			
			// look for our poker
			var len:int = cards.length;
			var num:int = 1;
			for ( var i:int = 1; i < len; i++ )
			{
				var card:Card 	= cards[i];
				var other:Card	= cards[i - 1];
						
				// see is it a match
				if ( card.value == other.value )
				{
					matchResults.bestHand.push( other );
					num++;
					if ( num == 4 )
					{
						matchResults.bestHand.push( card );
						
						// the cards are sorted on their value, so find the highest that's not our poker
						// in order to make our top 5 cards
						for( var j:int = 0; j < len; j++ )
						{
							if( cards[j].value != card.value )
							{
								matchResults.bestHand.push( cards[j] );
								break;
							}
						}
						
						// it's a match, set up the match results, and store them
						matchResults.type		= HandRank.POKER;
						matchResults.success	= true;
						
						// return our results
						return matchResults;
					}
				}
				else
				{
					num = 1;
					matchResults.bestHand.clear();
				}
			}
			
			// no match
			return matchResults; // success will be false as a result of the reset() call
		}
		
		/*******************************************************************************************/
		
		/**
		 * Sorts 2 cards based on their index
		 * @param a The first card
		 * @param b The second card
		 * @return If the first card is higher than the second
		 */
		private function _sort( a:Card, b:Card ):int
		{
			return b.value - a.value;
		}
	}

}