package logic.evaluators 
{
	import enums.CardValue;
	import enums.HandRank;
	import logic.Card;
	import logic.CardMatchResults;
	
	/**
	 * Checks a set of cards to see if there's a royal flush in there
	 */
	public class RoyalFlushEvaluator extends BaseEvaluator
	{
		 
		/**
		 * Creates a new RoyalFlushEvaluator
		 * @param evaluator The main Evaluator class, that holds us
		 */
		public function RoyalFlushEvaluator( evaluator:Evaluator )
		{
			super( evaluator );
		}
		
		/**
		 * Takes a group of cards and sees if there's a match for a royal flush
		 * @param cards The cards that we're trying to match
		 * @param matchResults The object to copy our match results into
		 * @return The results of the match
		 */
		public function match( cards:Vector.<Card>, matchResults:CardMatchResults ):CardMatchResults
		{
			// reset our results object
			matchResults.reset();
			
			// see if there's a straight flush first
			matchResults = this.m_evaluator.matchStraightFlush( cards, matchResults );
			if ( !matchResults.success )
				return matchResults; // there's no match royal flush for these cards, so return
			
			// if the high card isn't an ace, then there's no royal flush
			if ( matchResults.bestHand[0].value != CardValue.ACE )
			{
				matchResults.reset(); // reset as it's currently set as a match for a straight flush
				return matchResults;
			}
			
			// update the hand type
			matchResults.type = HandRank.ROYAL_FLUSH;
		
			// return our results
			return matchResults;
		}
		
	}

}