package logic.evaluators 
{
	import enums.HandRank;
	import logic.Card;
	import logic.CardMatchResults;
	
	/**
	 * Checks a set of cards to see if there's a straight flush in there
	 */
	public class StraightFlushEvaluator extends BaseEvaluator
	{
		 
		/**
		 * Creates a new StraightFlushEvaluator
		 * @param evaluator The main Evaluator class, that holds us
		 */
		public function StraightFlushEvaluator( evaluator:Evaluator )
		{
			super( evaluator );
		}
		
		/**
		 * Takes a group of cards and sees if there's a match for a straight flush
		 * @param cards The cards that we're trying to match
		 * @param matchResults The object to copy our results into
		 * @return The results of the match
		 */
		public function match( cards:Vector.<Card>, matchResults:CardMatchResults ):CardMatchResults
		{
			// reset our results object
			matchResults.reset();
			
			// see if there's a flush first
			matchResults = this.m_evaluator.matchFlush( cards, matchResults );
			if ( !matchResults.success )
				return matchResults; // there's no match straight flush for these cards, so return
			
			// there's the flush, now look for the straight
			matchResults = this.m_evaluator.matchStraight( cards, matchResults, matchResults.bestHand[0].suit ); // only check against the suit
			if ( !matchResults.success )
			{
				// there's flush, but no straight. return
				matchResults.reset();
				return matchResults;
			}
			
			// there's a straight flush, update our type
			matchResults.type = HandRank.STRAIGHT_FLUSH;
		
			// return our results
			return matchResults;
		}
		
	}

}