package logic.evaluators 
{
	import enums.HandRank;
	import logic.Card;
	import logic.CardMatchResults;
	
	/**
	 * Verifies if there's a set of trips in a given set of cards
	 */
	public class TripsEvaluator extends BaseEvaluator
	{
		 
		/**
		 * Creates a new TripsEvaluator
		 * @param evaluator The main Evaluator class, that holds us
		 */
		public function TripsEvaluator( evaluator:Evaluator )
		{
			super( evaluator );
		}
		
		/**
		 * Takes a group of cards and sees if there's a match for a set of trips
		 * @param cards The cards that we're trying to match
		 * @param matchResults The object to copy our match results into
		 * @return The results of the match
		 */
		public function match( cards:Vector.<Card>, matchResults:CardMatchResults ):CardMatchResults
		{
			// reset our results object
			matchResults.reset();
			
			// quick out
			if( cards.length < 3 )
				return matchResults;
			
			// sort the cards (so we always match the highest trips)
			cards.sort( this._sort );
			
			// look for our trips match
			var len:int = cards.length;
			var num:int = 1;
			for ( var i:int = 1; i < len; i++ )
			{
				var card:Card 	= cards[i];
				var other:Card	= cards[i - 1];
						
				// see is it a match
				if ( card.value == other.value )
				{
					matchResults.bestHand.push( other );
					num++;
					if ( num == 3 )
					{
						matchResults.bestHand.push( card );
						
						// our cards are sorted from lowest to highest, so go through and pick
						// the two other highest cards to make our best hand
						for( var j:int = 0; j < len; j++ )
						{
							if( cards[j].value != card.value )
							{
								matchResults.bestHand.push( cards[j] );
								if( matchResults.bestHand.length == 5 )
									break;
							}
						}
						
						// it's a match, set up the match results, and store them
						matchResults.type		= HandRank.TRIPS;
						matchResults.success	= true;
					
						// return our results
						return matchResults;
					}
				}
				else
				{
					num = 1;
					matchResults.bestHand.clear();
				}
			}
			
			// no match
			return matchResults; // success will be false as a result of the reset() call
		}
		
		/*******************************************************************************************/
		
		/**
		 * Sorts 2 cards based on their index
		 * @param a The first card
		 * @param b The second card
		 * @return If the first card is higher than the second
		 */
		private function _sort( a:Card, b:Card ):int
		{
			return b.value - a.value;
		}
		
	}

}