package logic.evaluators 
{
	import enums.HandRank;
	import logic.Card;
	import logic.CardMatchResults;
	
	/**
	 * Verifies if there's two pairs in a given set of cards
	 */
	public class TwoPairEvaluator extends BaseEvaluator
	{
		 
		/**
		 * Creates a new TwoPairEvaluator
		 * @param evaluator The main Evaluator class, that holds us
		 */
		public function TwoPairEvaluator( evaluator:Evaluator )
		{
			super( evaluator );
		}
		
		/**
		 * Takes a group of cards and sees if there's a match for two pairs
		 * @param cards The cards that we're trying to match
		 * @param matchResults The object to copy our match results into
		 * @return The results of the match
		 */
		public function match( cards:Vector.<Card>, matchResults:CardMatchResults ):CardMatchResults
		{
			// reset our results object
			matchResults.reset();
			
			// quick out
			if( cards.length < 4 )
				return matchResults;
			
			// see is there a first pair
			matchResults = this.m_evaluator.matchPair( cards, matchResults, null );
			if ( !matchResults.success )
				return matchResults;
			
			// store the results of the first match
			var card1:Card 	= matchResults.bestHand[0];
			var card2:Card	= null;
			
			// there's at least one pair, so look for a second
			matchResults = this.m_evaluator.matchPair( cards, matchResults, card1.value );
			if ( !matchResults.success )
			{
				// there's one pair, but not two, return
				matchResults.reset();
				return matchResults;
			}
			
			// hold our second pair card
			card2 = matchResults.bestHand[0];
			
			// fill in our best hand - our cards vector should already be sorted
			matchResults.bestHand.clear();
			matchResults.bestHand.push( card1 ); // temporary
			matchResults.bestHand.push( card1 ); // temporary
			matchResults.bestHand.push( card2 ); // temporary
			matchResults.bestHand.push( card2 ); // temporary
			var len:int = cards.length;
			for( var i:int = 0; i < len; i++ )
			{
				var card:Card = cards[i];
				if( card.value == card1.value && card != card1 )
					matchResults.bestHand[1] = card; // it's the other card from the first pair
				else if( card.value == card2.value && card != card2 )
					matchResults.bestHand[3] = card; // it's the other card from the second pair
				else if( card.value != card1.value && card.value != card2.value && matchResults.bestHand.length == 4 )
					matchResults.bestHand.push( card ); // the highest card that's not one of our pairs
			}
			
			// there's 2 pairs, store the results in our cache
			matchResults.type		= HandRank.TWO_PAIR;
			matchResults.success	= true;
		
			// return our results
			return matchResults;
		}
		
	}

}