package state
{
    import cocos2d.CCScaledLayer;
	
	import Loom.GameFramework.ITicked;
	import Loom.GameFramework.TimeManager;
	
	import logic.MainPlayer;
	
	/**
	 * Define a delegate so we can add callbacks to the game state
	 */
	public delegate GameStateCallback():void;
	
	/**
	 * A GameState class - we can only be in one state at a time
	 */
	public class GameState implements ITicked
	{
		
		/**********************************************************************/
		
		/**
		 * The callback called when we've began the state. It should take no parameters
		 */
		public var onBegin:GameStateCallback = null;
		
		/**
		 * The callback called when we've ended the state. It should take no parameters
		 */
		public var onEnd:GameStateCallback = null;
		
		/**
		 * The TimeManager that controls the playback of time on us
		 */
		[Inject]
		public var timeManager:TimeManager = null;
		
		/**
		 * The GameStateManager that controls us
		 */
		[Inject]
		public var stateManager:GameStateManager = null;
		
		/**
		 * The main player for the game
		 */
		[Inject]
		public var mainPlayer:MainPlayer = null;
		
		/**
		 * The main canvas for the gui
		 */
		[Inject]
		public var guiCanvas:CCScaledLayer = null;
		
		/**********************************************************************/
		
		private var m_name:String = null; // the name for our game state
		
		/**********************************************************************/
		
		/**
		 * The name for our game state
		 */
		public function get name():String { return this.m_name; }
		
		/**********************************************************************/
		
		/**
		 * Creates a new GameState
		 * @param name The name of our game state
		 */
		public function GameState( name:String )
		{
			this.m_name = name;
		}
		
		/**
		 * Inits the GameState - at this point, any injection is complete
		 */
		public function init():void
		{
		}
		
		/**
		 * Resets the GameState - sometimes you need to persist info across multiple
		 * state begin() and end(), so this lets us say "reset everything"
		 */
		public function reset():void
		{
		}
		
		/**
		 * Destroys the GameState and clears it for garbage collection
		 */
		public function destroy():void
		{
			// call end(), which should clear everything up
			this.onEnd = null; // so we don't call a callback
			this.end();
			
			// clear our properties
			this.onBegin		= null;
			this.timeManager	= null;
			this.stateManager	= null;
			this.mainPlayer		= null;
			this.guiCanvas		= null;
		}
		
		/**
		 * Called when we begin this game state
		 * @param param An optional param
		 */
		public function begin( param:Object = null ):void
		{
			this.onBegin();
		}
		
		/**
		 * Called when we end this game state
		 */
		public function end():void
		{
			this.onEnd();
		}
		
		/**
		 * Called every tick that we're active
		 */
		public function onTick():void
		{
			// override in super
			Math.random(); 	// math random doesn't seem to be seeded properly, resulting in the same hands when you play
							// so this is to try and alievate that
		}
	}
}