package state
{
	import gui.MoneyStack;
	import gui.PlayActionButtons;
	import logic.AIPlayer;
	import logic.Deck;
	import logic.evaluators.Evaluator;
	
	/**
	 * A PokerGameState class, for the different poker states; pre-flop, flop etc
	 */
	public class PokerGameState extends GameState
	{
		
		/**********************************************************************/
		
		/**
		 * The AI player that we're playing against
		 */
		[Inject]
		public var opponent:AIPlayer = null;
		
		/**
		 * The card deck for the game
		 */
		[Inject]
		public var deck:Deck = null;
		
		/**
		 * The action buttons for the player (check, raise, etc)
		 */
		[Inject]
		public var actionButtons:PlayActionButtons = null;
		
		/**
		 * The main pot for the game
		 */
		[Inject]
		public var mainPot:MoneyStack = null;
		
		/**
		 * The evaluator for finding our best hand
		 */
		[Inject]
		public var cardEvaluator:Evaluator = null;
		
		/**********************************************************************/
		
		/**
		 * Creates a new PokerGameState
		 * @param name The name of our game state
		 */
		public function PokerGameState( name:String )
		{
			super( name );
		}
		
		/**
		 * Destroys the PokerGameState and clears it for garbage collection
		 */
		override public function destroy():void
		{
			super.destroy();
			
			// clear our properties
			this.opponent		= null;
			this.deck 			= null;
			this.actionButtons	= null;
			this.mainPot		= null;
			this.cardEvaluator	= null;
		}
	}
}