package state
{
	import constants.PokerStates;
	import logic.Player;

	/**
	 * The dealer state, where we choose/change our dealer
	 */
	public class PokerStateDealer extends PokerGameState
	{
		
		/**********************************************************************/
		
		private var m_dealer:Player		= null; // the current dealer
		private var m_currTime:Number	= 0.0;	// our current timer
		private var m_waitTime:Number	= 2.0;	// how long to wait for
		
		/**********************************************************************/
		
		/**
		 * Creates a new PokerStateDealer
		 */
		public function PokerStateDealer()
		{
			super( PokerStates.DEALER );
		}
		
		/**
		 * Resets the dealer state
		 */
		override public function reset():void
		{
			this.m_dealer = null; // clear our dealer, so we choose fresh next time
		}
		
		/**
		 * Destroys the dealer state and clears it for garbage collection
		 */
		override public function destroy():void
		{
			super.destroy();
			
			// null our properties
			this.m_dealer = null;
		}
		
		/**
		 * Called when we're coming into this state - choose our dealer
		 * @param param An optional param
		 */
		override public function begin( param:Object = null ):void
		{
			super.begin( param );
			
			// reset our current time
			this.m_currTime	= 0.0;
			
			// get our dealer - if we don't have one, then it's the opponent
			if( this.m_dealer == null )
				this.m_dealer = this.opponent;
			else
			{
				this.m_dealer.isDealer	= false; // clear them
				this.m_dealer 			= ( this.m_dealer == this.opponent ) ? this.mainPlayer : this.opponent;
			}
				
			// set it on the player
			this.m_dealer.isDealer = true;
			Console.print( "[PokerStateDealer] The dealer for this round is " + this.m_dealer );
			
			// up the player's states
			this.mainPlayer.statsNumHands += 1;
			
			// reset the all-in boolean
			this.mainPlayer.isAllIn = false;
			this.opponent.isAllIn	= false;
		}
		
		/**
		 * Called every tick we're active - wait a bit before changing
		 */
		override public function onTick():void
		{
			super.onTick();
			
			// we wait a bit for any animations that are playing during this state
			var dt:Number 	= this.timeManager.TICK_RATE;
			this.m_currTime	+= dt;
			if( this.m_currTime >= this.m_waitTime )
				this.stateManager.changeState( PokerStates.PRE_FLOP );
		}
		
	}
	
}