package state
{
	import constants.PokerStates;
	import gui.popups.PopupWinLose;

	/**
	 * The end match state, where we show the player their stats
	 */
	public class PokerStateEndMatch extends PokerGameState
	{
		
		/**********************************************************************/
		
		private var m_popup:PopupWinLose = null; // the popup to show
		
		/**********************************************************************/
		
		/**
		 * Creates a new PokerStateEndMatch
		 */
		public function PokerStateEndMatch()
		{
			super( PokerStates.END_MATCH );
		}
		
		/**
		 * Inits the PokerStateEndMatch - called after injection
		 */
		override public function init():void
		{
			super.init();
			
			// create our popup
			this.m_popup = new PopupWinLose( this.guiCanvas.designWidth, this.guiCanvas.designHeight );
		}
		
		/**
		 * Destroys teh PokerStateEndMatch and clears it for garbage collection
		 */
		override public function destroy():void
		{
			super.destroy();
			
			// destroy our popup
			this.m_popup.destroy();
			
			// clear our params
			this.m_popup = null;
		}
		
		/**
		 * Called when we're coming into this state - choose our dealer
		 * @param param An optional param
		 */
		override public function begin( param:Object = null ):void
		{
			super.begin( param );
			
			// did the player win
			var didWin:Boolean = ( param as Boolean );
			
			// up the player's stats
			if( didWin )
				this.mainPlayer.statsCashWon += this.opponent.buyIn;
			else
				this.mainPlayer.statsCashLost += this.opponent.buyIn;
			
			// show our popup
			this.m_popup.onHide += this._onPopupHide;
			this.m_popup.showPlayerStats( this.mainPlayer, didWin );
			this.guiCanvas.addChild( this.m_popup );
		}
		
		/**
		 * Called when this state is ending - clean up
		 */
		override public function end():void
		{
			super.end();
			
			// make sure our popup isn't showing
			this.m_popup.onHide -= this._onPopupHide;
			this.m_popup.hide();
		}
		
		/**********************************************************************/
		
		// called when we're hiding our popup
		private function _onPopupHide():void
		{
			// move to the wait state until we have a new opponent
			this.stateManager.changeState( PokerStates.WAIT );
		}
		
	}
	
}