package state
{
	import constants.PokerStates;
	import enums.CardDealDest;

	/**
	 * The flop state, where we deal our flop
	 */
	public class PokerStateFlop extends PokerGameState
	{
		
		/**********************************************************************/
		
		private var m_currTime:Number	= 0.0;	// our current timer
		private var m_waitTime:Number	= 1.0;	// how long to wait for
		private var m_isDealing:Boolean	= false;// are we currently dealing our cards?
		
		/**********************************************************************/
		
		/**
		 * Creates a new PokerStateFlop
		 */
		public function PokerStateFlop()
		{
			super( PokerStates.FLOP );
		}
		
		/**
		 * Called when we're coming into this state - deal our flop
		 * @param param An optional param
		 */
		override public function begin( param:Object = null ):void
		{
			super.begin( param );
			
			// reset our current time
			this.m_currTime		= 0.0;
			this.m_isDealing	= true;
			
			// deal our flop cards
			this.deck.burn();
			this.deck.deal( CardDealDest.FLOP_1, 0.5 );
			this.deck.deal( CardDealDest.FLOP_2, 0.6 );
			this.deck.deal( CardDealDest.FLOP_3, 0.7 );
		}
		
		/**
		 * Called every tick we're active - wait a bit before changing
		 */
		override public function onTick():void
		{
			super.onTick();
			
			// wait for a bit
			var dt:Number	= this.timeManager.TICK_RATE;
			this.m_currTime	+= dt;
			if( this.m_currTime < this.m_waitTime )
				return;
			
			// move onto the betting state
			this.stateManager.changeState( PokerStates.BET, this.name );
		}
		
	}
	
}