package state
{
	import constants.PokerStates;
	import enums.CardDealDest;
	import logic.Card;

	/**
	 * The pre-flop state, where we pay the blinds, deal our hole cards
	 */
	public class PokerStatePreFlop extends PokerGameState
	{
		
		/**********************************************************************/
		
		private var m_currTime:Number		= 0.0;	// our current timer
		private var m_waitTime:Number		= 1.0;	// how long to wait for
		private var m_isShuffling:Boolean	= false;// are we currently shuffling?
		private var m_isDealing:Boolean		= false;// are we currently dealing our cards?
		
		/**********************************************************************/
		
		/**
		 * Creates a new PokerStatePreFlop
		 */
		public function PokerStatePreFlop()
		{
			super( PokerStates.PRE_FLOP );
		}
		
		/**
		 * Called when we're coming into this state - shuffle and deal the hold cards
		 * @param param An optional param
		 */
		override public function begin( param:Object = null ):void
		{
			super.begin( param );
			
			// reset our current time
			this.m_currTime		= 0.0;
			this.m_isShuffling	= true;
			this.m_isDealing	= false;
			
			// shuffle our deck
			this.deck.shuffle();
		}
		
		/**
		 * Called every tick we're active - wait a bit before changing
		 */
		override public function onTick():void
		{
			super.onTick();
			
			// wait for a bit
			var dt:Number	= this.timeManager.TICK_RATE;
			this.m_currTime	+= dt;
			if( this.m_currTime < this.m_waitTime )
				return;
				
			// if we're shuffling, move to dealing
			if( this.m_isShuffling )
			{
				this.m_isShuffling 	= false;
				this.m_isDealing	= true;
				this.m_currTime		= 0.0;
				
				// depending on who's dealer, deal them first
				var playerIsDealer:Boolean	= this.mainPlayer.isDealer;
				var dest1:CardDealDest 		= ( playerIsDealer ) ? CardDealDest.OPPONENT_HOLE_1 : CardDealDest.PLAYER_HOLE_1;
				var dest2:CardDealDest 		= ( playerIsDealer ) ? CardDealDest.PLAYER_HOLE_1 : CardDealDest.OPPONENT_HOLE_1;
				var dest3:CardDealDest 		= ( playerIsDealer ) ? CardDealDest.OPPONENT_HOLE_2 : CardDealDest.PLAYER_HOLE_2;
				var dest4:CardDealDest 		= ( playerIsDealer ) ? CardDealDest.PLAYER_HOLE_2 : CardDealDest.OPPONENT_HOLE_2;
				
				// deal our cards
				var card1:Card = this.deck.deal( dest1, 0.0 );
				var card2:Card = this.deck.deal( dest2, 0.1 );
				var card3:Card = this.deck.deal( dest3, 0.2 );
				var card4:Card = this.deck.deal( dest4, 0.3 );
				
				// set the opponent hole cards
				this.mainPlayer.holeCard1	= ( playerIsDealer ) ? card2 : card1;
				this.mainPlayer.holeCard2	= ( playerIsDealer ) ? card4 : card3;
				this.opponent.holeCard1 	= ( playerIsDealer ) ? card1 : card2;
				this.opponent.holeCard2 	= ( playerIsDealer ) ? card3 : card4;
			}
			else if( this.m_isDealing )
				this.stateManager.changeState( PokerStates.BET, this.name );
		}
		
	}
	
}