package state
{
	import cocos2d.ccColor3B;
	import CocosDenshion.SimpleAudioEngine;
	
	import constants.Resources;
	import constants.States;
	import gui.Image;
	import gui.TextField;

	/**
	 * The DS state, where we show our logo
	 */
	public class StateDS extends MainGameState
	{
		
		/**********************************************************************/
		
		private var m_logo:Image 			= null;	// the divillysausages logo
		private var m_url:TextField			= null; // the divillysausages url
		private var m_fadingIn:Boolean		= false;// are we fading our stuff in?
		private var m_fadeInSpeed:Number	= 2.0;	// how fast to fade in
		private var m_fadeOutSpeed:Number	= 0.5;	// how fast to fade out
		private var m_playedSound:Boolean	= false;// have we played our sound yet?
		private var m_currTime:Number		= 0.0;	// our current timer
		private var m_waitTime:Number		= 1.0;	// how long to wait for
		
		/**********************************************************************/
		
		/**
		 * Creates a new StateDS
		 */
		public function StateDS()
		{
			super( States.DS );
			
			// create our logo
			this.m_logo = new Image( Resources.ATLAS_SPRITES, Resources.SPRITE_DS_LOGO );
			
			// create our url
			this.m_url 			= new TextField( "http://divillysausages.com", Resources.FONT_CURSE, new ccColor3B( 75, 207, 49 ) );
			this.m_url.scale	= 0.25;
		}
		
		/**
		 * Destroys the DS state and clears it for garbage collection
		 */
		override public function destroy():void
		{
			super.destroy();
			
			// destroy any objects
			this.m_logo.destroy();
			this.m_url.destroy();
			
			// null our properties
			this.m_logo	= null;
			this.m_url	= null;
		}
		
		/**
		 * Called when we're coming into this state - show our objects
		 * @param param An optional param
		 */
		override public function begin( param:Object = null ):void
		{
			super.begin( param );
			
			// set our props
			this.m_playedSound	= false;
			this.m_fadingIn	 	= true;
			this.m_currTime		= 0.0;
			
			// get our total height
			var th:Number = this.m_logo.height + this.m_url.height;
			
			// position our elements
			this.m_logo.x 	= int( this.guiCanvas.designWidth * 0.5 - this.m_logo.width * 0.5 );
			this.m_logo.y 	= int( this.guiCanvas.designHeight * 0.5 + th * 0.5 );
			this.m_url.x	= int( this.guiCanvas.designWidth * 0.5 - this.m_url.width * 0.5 );
			this.m_url.y	= int( this.m_logo.y - this.m_logo.height );
			
			// hide them
			this.m_logo.alpha 	= 0.0;
			this.m_url.alpha	= 0.0;
			
			// add our elements
			this.guiCanvas.addChild( this.m_logo );
			this.guiCanvas.addChild( this.m_url );
		}
		
		/**
		 * Called when we're leaving this state - remove our objects
		 */
		override public function end():void
		{
			super.end();
			
			// remove our elements
			this.guiCanvas.removeChild( this.m_logo, false );
			this.guiCanvas.removeChild( this.m_url, false );
		}
		
		/**
		 * Called every tick we're active - show our objects
		 */
		override public function onTick():void
		{
			super.onTick();
			var dt:Number = this.timeManager.TICK_RATE;
			
			// fade in
			if( this.m_fadingIn )
			{
				if( this.m_logo.alpha < 1.0 )
				{
					this.m_logo.alpha 	+= this.m_fadeInSpeed * dt;
					this.m_url.alpha	+= this.m_fadeInSpeed * dt;
				}
				else
				{
					// play our sound
					if( !this.m_playedSound )
					{
						SimpleAudioEngine.sharedEngine().playEffect( Resources.SOUND_COIN );
						this.m_playedSound = true;
					}
					
					// wait a bit
					this.m_currTime += dt;
					if( this.m_currTime >= this.m_waitTime )
						this.m_fadingIn = false;
				}
			}
			else
			{
				if( this.m_logo.alpha > 0.0 )
				{
					this.m_logo.alpha 	-= this.m_fadeOutSpeed * dt;
					this.m_url.alpha	-= this.m_fadeOutSpeed * dt;
				}
				else
					this.stateManager.changeState( States.MENU );
			}
		}
		
	}
	
}